@@ -298,7 +298,7 @@ int zuluCryptEXEOpenVolume( const struct_opts * opts,const char * mapping_name,u
 	open_struct_t volume ;
 
 	struct stat statstr ;
-
+#if 0
 	/*
 	 * zuluCryptVolumeIsInSystemVolumeList() is defined in volumes.c
 	 */
@@ -311,6 +311,7 @@ int zuluCryptEXEOpenVolume( const struct_opts * opts,const char * mapping_name,u
 			return zuluExit( 22,device,mount_point,stl ) ;
 		}
 	}
+#endif
 	if( m_opts == NULL ){
 
 		m_opts = "rw" ;
@@ -415,7 +416,13 @@ int zuluCryptEXEOpenVolume( const struct_opts * opts,const char * mapping_name,u
 		/*
 		 * zuluCryptPluginManagerGetKeyFromModule is defined in ../pluginManager/zuluCryptPluginManager.c
 		 */
-		*passphrase = zuluCryptPluginManagerGetKeyFromModule( device_path,plugin_path,uuid,uid,opts,&st ) ;
+		*passphrase = zuluCryptPluginManagerGetKeyFromModule( device_path,
+								      plugin_path,
+								      uuid,
+								      uid,
+								      opts,
+								      zuluCryptRunTimePath(),
+								      &st ) ;
 
 		StringFree( device_path ) ;
 		StringFree( uuid ) ;
@@ -462,14 +469,14 @@ int zuluCryptEXEOpenVolume( const struct_opts * opts,const char * mapping_name,u
 
 		}else if( StringsAreEqual( source,"-f" ) ){
 
-			if( StringHasNoComponent( pass,"/.zuluCrypt-socket" ) ){
+			if( StringHasNoComponent( pass,zuluCryptRunTimePath() ) ){
 
 				tcrypt_keyfile = 1 ;
 			}
 			/*
 			 * function is defined at "path_access.c"
 			 */
-			switch( zuluCryptGetPassFromFile( pass,uid,data ) ){
+			switch( zuluCryptGetPassFromFile( NULL,pass,uid,data ) ){
 
 				case 1 : return zuluExit_1( 16,opts,device,mount_point,stl ) ;
 				case 2 : return zuluExit_1( 17,opts,device,mount_point,stl ) ;
@@ -516,15 +523,20 @@ int zuluCryptEXEOpenVolume( const struct_opts * opts,const char * mapping_name,u
 	volume.iteration_count = v_info.iteration_count ;
 
 	volume.veraCrypt_volume = StringAtLeastOneMatch( v_info.type,"vcrypt","veracrypt","vera",NULL ) ;
+	volume.trueCrypt_volume = StringAtLeastOneMatch( v_info.type,"tcrypt","truecrypt",NULL ) ;
 
-	if( !volume.veraCrypt_volume ){
+	if( !volume.veraCrypt_volume && !volume.trueCrypt_volume ){
 
 		if( opts->offset != NULL ){
 
 			*offset = String( "/dev/urandom.aes.cbc-essiv:sha256.256.ripemd160." ) ;
 			volume.plain_dm_properties = StringAppend( *offset,opts->offset ) ;
 		}else{
-			if( StringsAreNotEqual( opts->type,"luks" ) ){
+			if( StringsAreEqual( opts->type,"plain" ) ){
+
+				volume.plain_dm_properties = "aes.cbc-essiv:sha256.256.sha256.0" ;
+
+			}else if( StringsAreNotEqual( opts->type,"luks" ) ){
 
 				volume.plain_dm_properties = opts->type ;
 			}
@@ -533,7 +545,10 @@ int zuluCryptEXEOpenVolume( const struct_opts * opts,const char * mapping_name,u
 
 	StringDelete( &v_info.type ) ;
 
-	plugin_path = plugin_path + StringLastIndexOfChar_1( plugin_path,'/' ) + 1 ;
+	if( plugin_path != NULL ){
+
+		plugin_path = plugin_path + StringLastIndexOfChar_1( plugin_path,'/' ) + 1 ;
+	}
 
 	volume.luks_detached_header = StringHasComponent( plugin_path,"luks" ) ;
 
