@@ -25,6 +25,7 @@
 #include <sys/mount.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <string.h>
 
 #include "zuluplay_support.h"
 #include "check_tcrypt.h"
@@ -93,7 +94,7 @@ string_t zuluCryptCreateKeyFile_1( string_t st,const char * fileName )
 	return zuluCryptCreateKeyFile( StringContent( st ),StringLength( st ),fileName ) ;
 }
 
-static int _open_tcrypt_volume( const char * device,const resolve_path_t * opt )
+static int _open_tcrypt_volume( const char * device,const open_struct_t * opts )
 {
 	tc_api_task task ;
 	int r = !TC_OK ;
@@ -105,11 +106,6 @@ static int _open_tcrypt_volume( const char * device,const resolve_path_t * opt )
 
 	const char * e ;
 
-	/*
-	 * open_struct_t is defined in includes.h
-	 */
-	const open_struct_t * opts = opt->args ;
-
 	string_t st = StringVoid ;
 
 	if( tc_api_initialize() ){
@@ -172,19 +168,19 @@ static int _open_tcrypt_volume( const char * device,const resolve_path_t * opt )
 
 static int _open_tcrypt_volume_1( const char * device,const resolve_path_t * opt )
 {
-	int r = _open_tcrypt_volume( device,opt ) ;
+	int r = _open_tcrypt_volume( device,opt->args ) ;
 
-	open_struct_t * opts ;
+	open_struct_t opts ;
 
 	if( r == 0 ){
 
 		return r ;
 	}else{
-		opts = ( open_struct_t * ) opt->args ;
+		memcpy( &opts,opt->args,sizeof( opts ) ) ;
 
-		opts->use_backup_header = 1 ;
+		opts.use_backup_header = 1 ;
 
-		return _open_tcrypt_volume( device,opt ) ;
+		return _open_tcrypt_volume( device,&opts ) ;
 	}
 }
 
