@@ -20,28 +20,36 @@
 #ifndef CHECKFORUPDATES_H
 #define CHECKFORUPDATES_H
 
-#include <QVector>
 #include <QObject>
 #include <QWidget>
+#include <QTimer>
+#include <QString>
+#include <QByteArray>
 
 #include "networkAccessManager.hpp"
 
+#include <utility>
+#include <array>
+
 class checkForUpdates : public QObject
 {
-	Q_OBJECT
 public:
-	static bool autoCheck( void ) ;
-	static void autoCheck( bool ) ;
+	void run( const QString& ) ;
+	void run() ;
 
-	checkForUpdates( QWidget *,bool ) ;
-
-	static void instance( QWidget *,const QString& ) ;
-	static void instance( QWidget * ) ;
+	checkForUpdates( QWidget * widget ) ;
 private:
-	void show( const QByteArray&,const QByteArray& ) ;
+	void check( bool ) ;
+	void showResult( const QString& ) ;
+	QString parseResult( const QByteArray& ) ;
+
 	QWidget * m_widget ;
+
+	NetworkAccessManager m_network ;
+
+	QNetworkRequest m_networkRequest ;
+
 	bool m_autocheck ;
-	NetworkAccessManager m_networkAccessManager ;
-};
+} ;
 
 #endif // CHECKFORUPDATES_H
