@@ -322,7 +322,7 @@ void luksaddkey::pbOpenFile( void )
 
 void luksaddkey::pbOpenPartition( void )
 {
-	openvolume::instance( this ).showLuksOnly().ShowAllPartitions( [ this ]( const QString& e ){
+	openvolume::instance( this,false ).showLuksOnly().ShowAllPartitions( [ this ]( const QString& e ){
 
 		this->setFieldFocus() ;
 		this->ShowUI( e ) ;
@@ -332,6 +332,11 @@ void luksaddkey::pbOpenPartition( void )
 void luksaddkey::pbAdd( void )
 {
 	DialogMsg msg( this ) ;
+
+	this->disableAll() ;
+
+	utility::raii raii( [ this ](){ this->enableAll() ; } ) ;
+
 	auto ExistingKey = m_ui->textEditExistingPassphrase->text() ;
 
 	auto NewKey = m_ui->textEditPassphraseToAdd->text() ;
@@ -349,6 +354,14 @@ void luksaddkey::pbAdd( void )
 
 	m_volumePath = utility::resolvePath( m_volumePath ) ;
 
+	if( utility::requireSystemPermissions( m_volumePath ) ){
+
+		if( !utility::enablePolkit( utility::background_thread::False ) ){
+
+			return 	msg.ShowUIOK( tr( "ERROR!" ),tr( "Failed to enable polkit support" ) ) ;
+		}
+	}
+
 	if( existingKeyIsKeyFile ){
 
 		if( ExistingKey.isEmpty() ){
@@ -436,10 +449,10 @@ void luksaddkey::pbAdd( void )
 
 	m_isWindowClosable = false ;
 
-	this->disableAll() ;
-
 	m_veraCryptWarning.show( m_ui->cbVolumeType->currentIndex() == 2 ) ;
 
+	raii.cancel() ;
+
 	this->taskFinished( utility::exec( exe ).await() ) ;
 }
 
