@@ -369,6 +369,10 @@ void managevolumeheader::pbCreate()
 {
 	DialogMsg msg( this ) ;
 
+	this->disableAll() ;
+
+	utility::raii raii( [ this ](){ this->enableAll() ; } ) ;
+
 	if( m_ui->lineEditBackUpName->text().isEmpty() || m_ui->lineEditDevicePath->text().isEmpty() ){
 
 		return msg.ShowUIOK( tr( "ERROR!" ),tr( "Atleast one required field is empty" ) ) ;
@@ -380,14 +384,23 @@ void managevolumeheader::pbCreate()
 
 	auto device = utility::resolvePath( m_ui->lineEditDevicePath->text() ) ;
 
-	device.replace( "\"","\"\"\"" ) ;
-
 	auto backUp = m_ui->lineEditBackUpName->text().replace( "\"","\"\"\"" ) ;
 
 	QString exe ;
 
+	if( utility::requireSystemPermissions( device ) ){
+
+		if( !utility::enablePolkit( utility::background_thread::False ) ){
+
+			return 	msg.ShowUIOK( tr( "ERROR!" ),tr( "Failed to enable polkit support" ) ) ;
+		}
+	}
+
+	device.replace( "\"","\"\"\"" ) ;
+
 	if( m_operation == "backup" ){
 
+
 		m_saveHeader = 1 ;
 
 		if( m_ui->cbVolumeHeader->currentIndex() != 0 ){
@@ -476,18 +489,18 @@ void managevolumeheader::pbCreate()
 		exe += " -g /dev/urandom -e sys" ;
 	}
 
-	this->disableAll() ;
-
 	m_OperationInProgress = true ;
 
 	m_veraCryptWarning.show( m_ui->cbVolumeHeader->currentIndex() == 2 ) ;
 
+	raii.cancel() ;
+
 	this->taskFinished( utility::exec( utility::appendUserUID( exe ) ).await() ) ;
 }
 
 void managevolumeheader::pbOpenPartition()
 {
-	openvolume::instance( this ).ShowNonSystemPartitions( [ this ]( const QString& e ){
+	openvolume::instance( this,false ).ShowNonSystemPartitions( [ this ]( const QString& e ){
 
 		m_ui->lineEditDevicePath->setText( e ) ;
 
