@@ -88,6 +88,8 @@
 
 #include "zuluPolkit.h"
 
+#include "json.h"
+
 struct jsonResult
 {
 	bool finished ;
@@ -97,19 +99,23 @@ struct jsonResult
 	QByteArray stdOut ;
 };
 
-#if POLKIT_SUPPORT
+static std::function< void() > _failed_to_connect_to_zulupolkit ;
 
-#include "json.h"
+static QSettings * _settings ;
 
 static QByteArray _json_command( const QByteArray& cookie,
 				 const QByteArray& password,
-				 const QString& exe )
+				 const QString& exe,
+				 const QString& path = QString(),
+				 const QByteArray& data = QByteArray() )
 {
 	nlohmann::json json ;
 
 	json[ "cookie" ]   = cookie.constData() ;
 	json[ "password" ] = password.constData() ;
 	json[ "command" ]  = exe.toLatin1().constData() ;
+	json[ "path" ]     = path.toLatin1().constData() ;
+	json[ "data" ]     = data.constData() ;
 
 	return json.dump().c_str() ;
 }
@@ -117,50 +123,57 @@ static QByteArray _json_command( const QByteArray& cookie,
 static jsonResult _json_result( const QByteArray& e )
 {
 	try{
-		auto json = nlohmann::json::parse( e.constData() ) ;
+		if( !e.isEmpty() ){
 
-		return { json[ "finished" ].get< bool >(),
-			 json[ "exitCode" ].get< int >(),
-			 json[ "exitStatus" ].get< int >(),
-			 json[ "stdError" ].get< std::string >().c_str(),
-			 json[ "stdOut" ].get< std::string >().c_str() } ;
-	}catch( ... ){
-		return { false,255,255,"","" } ;
-	}
-}
+			auto json = nlohmann::json::parse( e.constData() ) ;
 
-#else
+			return { json[ "finished" ].get< bool >(),
+				 json[ "exitCode" ].get< int >(),
+				 json[ "exitStatus" ].get< int >(),
+				 json[ "stdError" ].get< std::string >().c_str(),
+				 json[ "stdOut" ].get< std::string >().c_str() } ;
+		}
 
-static QByteArray _json_command( const QByteArray& cookie,
-				 const QByteArray& password,
-				 const QString& exe )
-{
-	Q_UNUSED( cookie ) ;
-	Q_UNUSED( password ) ;
-	Q_UNUSED( exe ) ;
+	}catch( ... ){}
 
-	return QByteArray() ;
-}
-
-static jsonResult _json_result( const QByteArray& e )
-{
-	Q_UNUSED( e ) ;
 	return { false,255,255,"","" } ;
 }
 
-#endif
+static bool _connected( QLocalSocket& s )
+{
+	s.connectToServer( utility::helperSocketPath() ) ;
+
+	for( int i = 0 ; ; i++ ){
+
+		if( s.waitForConnected() ){
+
+			return true ;
+
+		}else if( i == 2 ){
+
+			utility::debug() << "ERROR: Failed To Connect To zuluPolkit" ;
+			break ;
+		}else{
+			utility::debug() << s.errorString() ;
+
+			utility::Task::suspendForOneSecond() ;
+		}
+	}
+
+	return false ;
+}
 
-static int staticGlobalUserId = -1 ;
 static QByteArray _cookie ;
+static bool _polkit_support = AUTO_ENABLE_POLKIT_SUPPORT ;
 
-::Task::future< utility::Task >& utility::Task::run( const QString& exe,bool e )
+::Task::future< utility::Task >& utility::Task::run( const QString& exe,USEPOLKIT e )
 {
 	return utility::Task::run( exe,-1,e ) ;
 }
 
-::Task::future< utility::Task >& utility::Task::run( const QString& exe,int s,bool e )
+::Task::future< utility::Task >& utility::Task::run( const QString& exe,int s,USEPOLKIT e )
 {
-	return ::Task::run< utility::Task >( [ = ](){
+	return ::Task::run( [ = ](){
 
 		auto env = QProcessEnvironment::systemEnvironment() ;
 
@@ -168,65 +181,62 @@ static QByteArray _cookie ;
 	} ) ;
 }
 
+void utility::polkitFailedWarning( std::function< void() > e )
+{
+	_failed_to_connect_to_zulupolkit = std::move( e ) ;
+}
+
 void utility::Task::execute( const QString& exe,int waitTime,
 			     const QProcessEnvironment& env,
 			     const QByteArray& password,
 			     const std::function< void() >& f,
-			     bool polkit )
+			     USEPOLKIT polkit )
 {
-	class Process : public QProcess{
-	public:
-		Process( const std::function< void() >& f ) : m_function( f )
-		{
-		}
-	protected:
-		void setupChildProcess()
-		{
-			m_function() ;
-		}
-	private:
-		std::function< void() > m_function ;
-	} p( f ) ;
-
-	p.setProcessEnvironment( env ) ;
-
-	if( polkit && utility::useZuluPolkit() ){
+	if( polkit == USEPOLKIT::True && utility::useZuluPolkit() ){
 
 		QLocalSocket s ;
 
-		s.connectToServer( utility::helperSocketPath() ) ;
+		if( _connected( s ) ){
 
-		for( int i = 0 ; ; i++ ){
+			s.write( _json_command( _cookie,password,exe ) ) ;
 
-			if( s.waitForConnected() ){
+			s.waitForBytesWritten() ;
 
-				break ;
+			s.waitForReadyRead() ;
 
-			}else if( i == 10 ){
+			auto e = _json_result( s.readAll() ) ;
 
-				utility::debug() << "ERROR: Failed To Start Helper Application" ;
-				return ;
-			}else{
-				utility::debug() << s.errorString() ;
+			m_finished   = e.finished ;
+			m_exitCode   = e.exitCode ;
+			m_exitStatus = e.exitStatus ;
+			m_stdError   = e.stdError ;
+			m_stdOut     = e.stdOut ;
+		}else{
+			_failed_to_connect_to_zulupolkit() ;
 
-				utility::Task::suspendForOneSecond() ;
-			}
+			m_finished   = false ;
+			m_exitCode   = -1 ;
+			m_exitStatus = -1 ;
+			m_stdError   = "" ;
+			m_stdOut     = QObject::tr( "zuluCrypt: Failed To Establish Connection With zuluPolkit" ).toLatin1() ;
 		}
-
-		s.write( _json_command( _cookie,password,exe ) ) ;
-
-		s.waitForBytesWritten() ;
-
-		s.waitForReadyRead() ;
-
-		auto e = _json_result( s.readAll() ) ;
-
-		m_finished   = e.finished ;
-		m_exitCode   = e.exitCode ;
-		m_exitStatus = e.exitStatus ;
-		m_stdError   = e.stdError ;
-		m_stdOut     = e.stdOut ;
 	}else{
+		class Process : public QProcess{
+		public:
+			Process( const std::function< void() >& f ) : m_function( f )
+			{
+			}
+		protected:
+			void setupChildProcess()
+			{
+				m_function() ;
+			}
+		private:
+			const std::function< void() >& m_function ;
+		} p( f ) ;
+
+		p.setProcessEnvironment( env ) ;
+
 		p.start( exe ) ;
 
 		if( !password.isEmpty() ){
@@ -246,54 +256,184 @@ void utility::Task::execute( const QString& exe,int waitTime,
 	}
 }
 
-void utility::startHelperExecutable( QObject * obj,const QString& arg,const char * slot,const char * slot1 )
+void utility::setDefaultEnvironment()
 {
-	if( !utility::useZuluPolkit() ){
+}
 
-		QMetaObject::invokeMethod( obj,slot,Q_ARG( bool,true ),Q_ARG( QString,QString() ) ) ;
+QString utility::passwordSocketPath()
+{
+	return "/tmp/zuluCrypt-" + QString::number( getuid() ) ;
+}
 
-		return ;
+#if QT_VERSION > QT_VERSION_CHECK( 5,0,0 )
+	#include <QStandardPaths>
+	QString utility::socketPath()
+	{
+		return QStandardPaths::writableLocation( QStandardPaths::RuntimeLocation ) ;
 	}
+#else
+	#include <QDesktopServices>
+	QString utility::socketPath()
+	{
+		return QDesktopServices::storageLocation( QDesktopServices::DataLocation ) ;
+	}
+#endif
 
+void utility::setSettingsObject( QSettings * e )
+{
+	_settings = e ;
+}
+
+QSettings& utility::settingsObject()
+{
+	return *_settings ;
+}
+
+static QString zuluPolkitExe()
+{
+	auto exe = utility::executableFullPath( "pkexec" ) ;
+
+	if( exe.isEmpty() ){
+
+		return QString() ;
+	}else{
+		return QString( "%1 %2 %3 fork" ).arg( exe,zuluPolkitPath,utility::helperSocketPath() ) ;
+	}
+}
+
+static ::Task::future< utility::Task >& _start_zulupolkit( const QString& e )
+{
 	QFile f( "/dev/urandom" ) ;
 
 	f.open( QIODevice::ReadOnly ) ;
 
 	_cookie = f.read( 16 ).toHex() ;
 
-	auto exe = utility::executableFullPath( "pkexec" ) ;
+	return ::Task::run( [ = ]{
 
-	if( !exe.isEmpty() ){
+		return utility::Task( e,
+				      -1,
+				      utility::systemEnvironment(),
+				      _cookie,
+				      [](){},
+				      utility::Task::USEPOLKIT::False ) ;
+	} ) ;
+}
 
-		exe = QString( "%1 %2 %3 fork" ).arg( exe,zuluPolkitPath,utility::helperSocketPath() ) ;
+void utility::startHelperExecutable( QObject * obj,const QString& arg,const char * slot,const char * slot1 )
+{
+	if( AUTO_ENABLE_POLKIT_SUPPORT ){
 
-		::Task::exec( [ = ](){
+		auto exe = zuluPolkitExe() ;
 
-			auto e = utility::Task::run( exe,false ).get() ;
+		if( !exe.isEmpty() ){
 
-			QMetaObject::invokeMethod( obj,
-						   slot,
-						   Q_ARG( bool,e.success() ),
-						   Q_ARG( QString,arg ) ) ;
-		} ) ;
+			_start_zulupolkit( exe ).then( [ = ]( const utility::Task& e ){
+
+				QMetaObject::invokeMethod( obj,
+							   slot,
+							   Q_ARG( bool,e.success() ),
+							   Q_ARG( QString,arg ) ) ;
+			} ) ;
+		}else{
+			DialogMsg().ShowUIOK( QObject::tr( "ERROR" ),
+					      QObject::tr( "Failed to locate pkexec executable" ) ) ;
+
+			QMetaObject::invokeMethod( obj,slot1 ) ;
+		}
 	}else{
-		DialogMsg().ShowUIOK( QObject::tr( "ERROR" ),QObject::tr( "Failed to locate pkexec executable" ) ) ;
-		QMetaObject::invokeMethod( obj,slot1 ) ;
+		QMetaObject::invokeMethod( obj,slot,Q_ARG( bool,true ),Q_ARG( QString,arg ) ) ;
 	}
 }
 
 QString utility::helperSocketPath()
 {
-	auto z = utility::homePath() + "/.zuluCrypt-socket/" ;
+	auto a = QString::number( getuid() ) ;
+	auto b = QCoreApplication::applicationName() ;
 
-	z += QCoreApplication::applicationName() + ".polkit.socket" ;
-
-	return z ;
+	return QString( "/tmp/zuluCrypt-%1/%2.polkit.socket" ).arg( a,b ) ;
 }
 
 bool utility::useZuluPolkit()
 {
-	return POLKIT_SUPPORT ;
+	return _polkit_support ;
+}
+
+bool utility::requireSystemPermissions( const QString& e,utility::background_thread thread )
+{
+	const char * exe ;
+	const char * group ;
+
+	if( QCoreApplication::applicationName() == "zuluCrypt" ){
+
+		exe = ZULUCRYPTzuluCrypt" -S" ;
+		group = "zulucrypt" ;
+	}else{
+		exe = zuluMountPath" -S" ;
+		group = "zulumount" ;
+	}
+
+	auto s = [ & ](){
+
+		if( thread == utility::background_thread::True ){
+
+			return utility::Task::run( exe ).get().stdOut() ;
+		}else{
+			return utility::Task::run( exe ).await().stdOut() ;
+		}
+	}() ;
+
+	if( utility::split( s ).contains( e ) ){
+
+		if( utility::userBelongsToGroup( group ) ){
+
+			return false ;
+		}else{
+			return true ;
+		}
+	}else{
+		return false ;
+	}
+}
+
+bool utility::enablePolkit( utility::background_thread thread )
+{
+	if( _polkit_support ){
+
+		return true ;
+	}
+
+	auto exe = zuluPolkitExe() ;
+
+	if( !exe.isEmpty() ){
+
+		auto socketPath = utility::helperSocketPath() ;
+
+		if( thread == utility::background_thread::True ){
+
+			if( _start_zulupolkit( exe ).get().success() ){
+
+				_polkit_support = true ;
+
+				while( !utility::pathExists( socketPath ) ){
+
+					utility::Task::waitForOneSecond() ;
+				}
+			}
+		}else{
+			if( _start_zulupolkit( exe ).await().success() ){
+
+				_polkit_support = true ;
+
+				while( !utility::pathExists( socketPath ) ){
+
+					utility::Task::suspendForOneSecond() ;
+				}
+			}
+		}
+	}
+
+	return _polkit_support ;
 }
 
 void utility::quitHelper()
@@ -315,6 +455,42 @@ void utility::quitHelper()
 	}
 }
 
+std::pair< bool,QByteArray > utility::privilegedReadConfigFile( const QString& path )
+{
+	if( utility::enablePolkit( utility::background_thread::False ) ){
+
+		QLocalSocket s ;
+
+		if( _connected( s ) ){
+
+			s.write( _json_command( _cookie,QByteArray(),"Read",path ) ) ;
+
+			s.waitForBytesWritten() ;
+
+			s.waitForReadyRead() ;
+
+			return { true,_json_result( s.readAll() ).stdOut } ;
+		}
+	}
+
+	return { false,QByteArray() } ;
+}
+
+void utility::privilegedWriteConfigFile( const QByteArray& data,const QString& path )
+{
+	if( utility::enablePolkit( utility::background_thread::False ) ){
+
+		QLocalSocket s ;
+
+		if( _connected( s ) ){
+
+			s.write( _json_command( _cookie,QByteArray(),"Write",path,data ) ) ;
+
+			s.waitForBytesWritten() ;
+		}
+	}
+}
+
 bool utility::reUseMountPointPath()
 {
 	return REUSE_MOUNT_POINT ;
@@ -325,27 +501,14 @@ bool utility::reUseMountPoint()
 	return utility::reUseMountPointPath() ;
 }
 
-void utility::setUID( int uid )
-{
-	if( utility::userIsRoot() || utility::useZuluPolkit() ){
-
-		staticGlobalUserId = uid ;
-	}
-}
-
 int utility::getUID()
 {
-	return staticGlobalUserId ;
+	return getuid() ;
 }
 
 int utility::getUserID()
 {
-	if( staticGlobalUserId == -1 ){
-
-		return getuid() ;
-	}else{
-		return staticGlobalUserId ;
-	}
+	return utility::getUID() ;
 }
 
 int utility::getGUID( int uid )
@@ -367,11 +530,11 @@ QString utility::getStringUserID()
 
 QString utility::appendUserUID( const QString& e )
 {
-	if( staticGlobalUserId == -1 ){
+	if( utility::useZuluPolkit() ){
 
-		return e ;
-	}else{
 		return e + " -K " + utility::getStringUserID() ;
+	}else{
+		return e ;
 	}
 }
 
@@ -514,12 +677,12 @@ void utility::createPlugInMenu( QMenu * menu,const QString& a,const QString& b,c
 
 ::Task::future<int>& utility::exec( const QString& exe )
 {
-	return ::Task::run<int>( [ exe ](){ return utility::Task( exe ).exitCode() ; } ) ;
+	return ::Task::run( [ exe ](){ return utility::Task( exe ).exitCode() ; } ) ;
 }
 
 ::Task::future<QStringList>& utility::luksEmptySlots( const QString& volumePath )
 {
-	return ::Task::run<QStringList>( [ volumePath ](){
+	return ::Task::run( [ volumePath ](){
 
 		auto e = utility::appendUserUID( "%1 -b -d \"%2\"" ) ;
 
@@ -548,7 +711,7 @@ void utility::createPlugInMenu( QMenu * menu,const QString& a,const QString& b,c
 
 ::Task::future<QString>& utility::getUUIDFromPath( const QString& dev )
 {
-	return ::Task::run<QString>( [ dev ](){
+	return ::Task::run( [ dev ](){
 
 		auto device = dev ;
 		device = device.replace( "\"", "\"\"\"" ) ;
@@ -600,11 +763,11 @@ void utility::dropPrivileges( int uid )
 
 ::Task::future<bool>& utility::openPath( const QString& path,const QString& opener )
 {
-	return ::Task::run<bool>( [ = ](){
+	return ::Task::run( [ = ](){
 
 		auto e = opener + " " + utility::Task::makePath( path ) ;
 
-		return utility::Task::run( e,false ).get().failed() ;
+		return utility::Task::run( e,utility::Task::USEPOLKIT::False ).get().failed() ;
 	} ) ;
 }
 
@@ -623,7 +786,7 @@ void utility::openPath( const QString& path,const QString& opener,
 
 static ::Task::future<QString>& _getKey( LXQt::Wallet::Wallet& wallet,const QString& volumeID )
 {
-	return ::Task::run<QString>( [ & ](){
+	return ::Task::run( [ & ]()->QString{
 
 		decltype( wallet.readValue( volumeID ) ) key ;
 
@@ -747,7 +910,7 @@ static bool _writeToVolume( int fd,const char * buffer,unsigned int bufferSize )
 
 ::Task::future< int >& utility::clearVolume( const QString& volume,std::atomic_bool * exit,size_t volumeSize,std::function< void( int ) > function )
 {
-	return ::Task::run<int>( [ volume,exit,volumeSize,function ](){
+	return ::Task::run( [ volume,exit,volumeSize,function ](){
 
 		auto volumePath = volume ;
 
@@ -893,38 +1056,24 @@ bool utility::pathPointsToAFolder( const QString& path )
 	}
 }
 
-static QString _language_path( const QString& program )
-{
-	return utility::homePath() + "/.zuluCrypt/" + program + ".lang" ;
-}
-
 QString utility::localizationLanguage( const QString& program )
 {
-	QFile f( _language_path( program ) ) ;
+	Q_UNUSED( program ) ;
 
-	if( f.open( QIODevice::ReadOnly ) ){
+	if( _settings->contains( "LocalizationLanguage" ) ){
 
-		QString e = f.readAll() ;
-
-		e.remove( "\n" ) ;
-
-		return e ;
+		return _settings->value( "LocalizationLanguage" ).toString() ;
 	}else{
+		_settings->setValue( "LocalizationLanguage","en_US" ) ;
+
 		return "en_US" ;
 	}
 }
 
 void utility::setLocalizationLanguage( const QString& program,const QString& language )
 {
-	QFile f( _language_path( program ) ) ;
-
-	if( f.open( QIODevice::WriteOnly | QIODevice::Truncate ) ){
-
-		f.write( language.toLatin1() ) ;
-
-		utility::changePathOwner( f ) ;
-		utility::changePathPermissions( f ) ;
-	}
+	Q_UNUSED( program ) ;
+	_settings->setValue( "LocalizationLanguage",language ) ;
 }
 
 QString utility::localizationLanguagePath( const QString& program )
@@ -969,14 +1118,19 @@ bool utility::pathIsWritable( const QString& path,bool isFolder )
 
 bool utility::configDirectoriesAreNotWritable( QWidget * w )
 {
-	auto a = utility::homePath() + "/.zuluCrypt" ;
-	auto b = utility::homePath() + "/.zuluCrypt-socket" ;
+	auto a = utility::socketPath() ;
+	auto b = utility::passwordSocketPath() ;
+
+	QDir().mkpath( b ) ;
+
+	utility::changePathOwner( b ) ;
+	utility::changePathPermissions( b,0700 ) ;
 
 	if( utility::pathIsWritable( a ) && utility::pathIsWritable( b ) ){
 
 		return false ;
 	}else{
-		auto e = QObject::tr( "\"%1\" Folder Must Be Writable.\n\"%2\" Folder Must Also Be Writable." ).arg( a,b ) ;
+		auto e = QObject::tr( "\"%1\" and \"%2\" Folders Must Be Writable." ).arg( a,b ) ;
 		DialogMsg( w ).ShowUIOK( QObject::tr( "ERROR" ),e ) ;
 		return true ;
 	}
@@ -1000,9 +1154,9 @@ QString utility::keyPath()
 
 	QByteArray data = f.read( 64 ) ;
 
-	QString a = utility::homePath() ;
+	QString a = utility::passwordSocketPath() ;
 
-	return QString( "%1/.zuluCrypt-socket/%2" ).arg( a,utility::hashPath( data ).mid( 1 ) ) ;
+	return QString( "%1/%2" ).arg( a,utility::hashPath( data ).mid( 1 ) ) ;
 }
 
 bool utility::eventFilter( QObject * gui,QObject * watched,QEvent * event,std::function< void() > function )
@@ -1185,7 +1339,7 @@ QString utility::resolvePath( const QString& path )
 
 		return utility::homePath() + "/" + path.mid( 2 ) ;
 
-	}else if( path.startsWith( "UUID=") ){
+	}else if( path.startsWith( "UUID= ") ){
 
 		return path ;
 
@@ -1362,67 +1516,50 @@ void utility::addToFavorite( const QString& dev,const QString& m_point )
 {
 	if( !( dev.isEmpty() || m_point.isEmpty() ) ){
 
-		auto fav = QString( "%1\t%2\n" ).arg( _partition_id_to_device_id( dev,true ),m_point ) ;
+		QStringList s ;
 
-		QFile f( utility::homePath() + "/.zuluCrypt/favorites" ) ;
+		if( _settings->contains( "Favotites" ) ){
 
-		f.open( QIODevice::WriteOnly | QIODevice::Append ) ;
+			 s = _settings->value( "Favotites" ).toStringList() ;
+		}
 
-		f.write( fav.toLatin1() ) ;
+		auto e = QString( "%1\t%2" ).arg( _partition_id_to_device_id( dev,true ),m_point ) ;
 
-		utility::changePathOwner( f ) ;
-		utility::changePathPermissions( f ) ;
+		s.append( e ) ;
+
+		_settings->setValue( "Favotites",s ) ;
 	}
 }
 
 QStringList utility::readFavorites()
 {
-	QFile f( utility::homePath() + "/.zuluCrypt/favorites" ) ;
+	if( _settings->contains( "Favotites" ) ){
 
-	if( f.open( QIODevice::ReadOnly ) ){
+		 QStringList l ;
 
-		QStringList l ;
+		 for( const auto& it : _settings->value( "Favotites" ).toStringList() ){
 
-		for( const auto& it : utility::split( f.readAll() ) ){
+			 if( it.startsWith( "/dev/disk/by-id" ) ){
 
-			if( it.startsWith( "/dev/disk/by-id" ) ){
+				 l.append( _device_id_to_partition_id( it ) ) ;
+			 }else{
+				 l.append( it ) ;
+			 }
+		 }
 
-				l.append( _device_id_to_partition_id( it ) ) ;
-			}else{
-				l.append( it ) ;
-			}
-		}
-
-		utility::changePathOwner( f ) ;
-		utility::changePathPermissions( f ) ;
-
-		return l ;
+		 return l ;
 	}else{
 		return QStringList() ;
 	}
 }
 
-void utility::removeFavoriteEntry( const QString& entry )
+void utility::removeFavoriteEntry( const QString& e )
 {
-	auto l = utility::readFavorites() ;
+	auto s = utility::readFavorites() ;
 
-	l.removeOne( entry ) ;
+	s.removeOne( e ) ;
 
-	QFile f( utility::homePath() + "/.zuluCrypt/favorites" ) ;
-
-	f.open( QIODevice::WriteOnly | QIODevice::Truncate ) ;
-
-	for( const auto& it : l ){
-
-		auto e = it.split( '\t' ) ;
-
-		auto q = QString( "%1\t%2\n" ).arg( _partition_id_to_device_id( e.at( 0 ),true ),e.at( 1 ) ) ;
-
-		f.write( q.toLatin1() ) ;
-	}
-
-	utility::changePathPermissions( f ) ;
-	utility::changePathOwner( f ) ;
+	_settings->setValue( "Favotites",s );
 }
 
 void utility::readFavorites( QMenu * m,bool truncate,bool showFolders )
@@ -1500,12 +1637,8 @@ bool utility::userHasGoodVersionOfWhirlpool()
 
 void utility::licenseInfo( QWidget * parent )
 {
-	QString s ;
-#if POLKIT_SUPPORT
-	s = "\nPolkit Support: YES" ;
-#else
-	s = "\nPolkit Support: NO" ;
-#endif
+	QString s = "\nGpg key fingerprint: E3AF84691424AD00E099003502FC64E8DEBF43A8" ;
+
 	QString license = QString( "%1\n\n\
 This program is free software: you can redistribute it and/or modify \
 it under the terms of the GNU General Public License as published by \
@@ -1540,37 +1673,17 @@ static utility::array_t _default_dimensions( const char * defaults )
 	return e ;
 }
 
-static utility::array_t _dimensions( const QString& path,const char * defaults,int size )
+static utility::array_t _dimensions( const char * defaults,int size )
 {
-	QFile f( path ) ;
+	if( _settings->contains( "Dimensions" ) ){
 
-	if( !f.exists() ){
-
-		if( f.open( QIODevice::WriteOnly | QIODevice::Truncate ) ){
-
-			utility::changePathPermissions( f ) ;
-
-			f.write( defaults ) ;
-
-			utility::changePathPermissions( f ) ;
-			utility::changePathOwner( f ) ;
-
-			f.close() ;
-		}else{
-			qDebug() << "failed to open config file" ;
-			return _default_dimensions( defaults ) ;
-		}
-	}
-
-	if( f.open( QIODevice::ReadOnly ) ){
-
-		auto l = utility::split( f.readAll(),' ' ) ;
+		auto l = _settings->value( "Dimensions" ).toStringList() ;
 
 		utility::array_t p ;
 
 		if( l.size() != size || size > int( p.size() ) ){
 
-			qDebug() << "failed to parse config file" ;
+			utility::debug() << "Failed to parse config file" ;
 			return _default_dimensions( defaults ) ;
 		}
 
@@ -1595,52 +1708,41 @@ static utility::array_t _dimensions( const QString& path,const char * defaults,i
 
 		return p ;
 	}else{
-		qDebug() << "failed to open config file" ;
 		return _default_dimensions( defaults ) ;
 	}
 }
 
 utility::array_t utility::getWindowDimensions( const QString& application )
 {
-	auto path = utility::homePath() + "/.zuluCrypt/" + application + "-gui-ui-options" ;
-
 	if( application == "zuluCrypt" ){
 
-		return _dimensions( path,"297 189 782 419 298 336 100",7 ) ;
+		return _dimensions( "297 189 782 419 298 336 100",7 ) ;
 	}else{
-		return _dimensions( path,"205 149 910 477 220 320 145 87 87",9 ) ;
+		return _dimensions( "205 149 910 477 220 320 145 87 87",9 ) ;
 	}
 }
 
 void utility::setWindowDimensions( const QString& application,const std::initializer_list<int>& e )
 {
-	auto path = utility::homePath() + "/.zuluCrypt/" + application + "-gui-ui-options" ;
+	Q_UNUSED( application ) ;
 
-	QFile f( path ) ;
+	QStringList s ;
 
-	if( f.open( QIODevice::WriteOnly | QIODevice::Truncate ) ){
+	for( const auto& it : e ){
 
-		utility::changePathPermissions( f ) ;
-
-		for( const auto& it : e ){
-
-			f.write( QString( QString::number( it ) + " " ).toLatin1() ) ;
-
-			utility::changePathPermissions( f ) ;
-			utility::changePathOwner( f ) ;
-		}
+		s.append( QString::number( it ) ) ;
 	}
+
+	_settings->setValue( "Dimensions",s ) ;
 }
 
 QFont utility::getFont( QWidget * widget )
 {
-	QString fontPath = utility::homePath() + "/.zuluCrypt/font" ;
+	if( !_settings->contains( "Font") ){
 
-	QFile x( fontPath ) ;
-
-	if( x.open( QIODevice::ReadOnly ) ){
-
-		auto l = utility::split( x.readAll() ) ;
+		return widget->font() ;
+	}else{
+		auto l = _settings->value( "Font" ).toStringList() ;
 
 		if( l.size() >= 4 ){
 
@@ -1677,45 +1779,32 @@ QFont utility::getFont( QWidget * widget )
 		}else{
 			return widget->font() ;
 		}
-	}else{
-		return widget->font() ;
 	}
 }
 
 void utility::saveFont( const QFont& Font )
 {
-	QFile f( utility::homePath() + "/.zuluCrypt/font" ) ;
+	auto s = QString( "%1\n%2\n" ).arg( Font.family(),QString::number( Font.pointSize() ) ) ;
 
-	if( f.open( QIODevice::WriteOnly | QIODevice::Truncate ) ){
+	if( Font.style() == QFont::StyleNormal ){
 
-		utility::changePathOwner( f ) ;
-		utility::changePathPermissions( f ) ;
+		s = s + "normal\n" ;
 
-		auto s = QString( "%1\n%2\n" ).arg( Font.family(),QString::number( Font.pointSize() ) ) ;
+	}else if( Font.style() == QFont::StyleItalic ){
 
-		if( Font.style() == QFont::StyleNormal ){
-
-			s = s + "normal\n" ;
-
-		}else if( Font.style() == QFont::StyleItalic ){
-
-			s = s + "italic\n" ;
-		}else{
-			s = s + "oblique\n" ;
-		}
-
-		if( Font.weight() == QFont::Normal ){
-
-			s = s + "normal\n" ;
-		}else{
-			s = s + "bold" ;
-		}
-
-		f.write( s.toLatin1() ) ;
-
-		utility::changePathPermissions( f ) ;
-		utility::changePathOwner( f ) ;
+		s = s + "italic\n" ;
+	}else{
+		s = s + "oblique\n" ;
 	}
+
+	if( Font.weight() == QFont::Normal ){
+
+		s = s + "normal\n" ;
+	}else{
+		s = s + "bold" ;
+	}
+
+	_settings->setValue( "Font",utility::split( s,'\n' ) ) ;
 }
 
 bool utility::runningInMixedMode()
@@ -1817,67 +1906,67 @@ int utility::pluginKey( QWidget * w,QByteArray * key,const QString& p )
 	return l.exec() ;
 }
 
-void utility::showTrayIcon( QAction * ac,QSystemTrayIcon * trayIcon,bool zuluCrypt )
+void utility::showTrayIcon( QAction * ac,QObject * obj,bool show )
 {
-	Q_UNUSED( zuluCrypt ) ;
+	bool opt_show = true ;
 
-	QFile f( utility::homePath() + "/.zuluCrypt/tray" ) ;
+	if( ac ){
 
-	if( !f.exists() ){
+		if( !_settings->contains( "ShowTrayIcon" ) ){
 
-		f.open( QIODevice::WriteOnly | QIODevice::Truncate ) ;
-		f.write( "1" ) ;
-		f.close() ;
+			_settings->setValue( "ShowTrayIcon",true ) ;
+		}
+
+		ac->setCheckable( true ) ;
+
+		if( _settings->value( "ShowTrayIcon" ).toBool() ){
+
+			ac->setChecked( true ) ;
+			opt_show = true ;
+		}else{
+			ac->setChecked( false ) ;
+			opt_show = false ;
+		}
 	}
 
-	f.open( QIODevice::ReadOnly ) ;
+	auto _show_tray = [ & ]{
 
-	char c ;
+		QMetaObject::invokeMethod( obj,"showTrayIcon",Qt::QueuedConnection,
+					   Q_ARG( bool,show ? show : opt_show ) ) ;
+	} ;
 
-	f.read( &c,1 ) ;
+	for( int i = 0 ; i < 10 ; i++ ){
 
-	ac->setCheckable( true ) ;
+		if( QSystemTrayIcon::isSystemTrayAvailable() ){
 
-	if( c == '1' ){
-
-		ac->setChecked( true ) ;
-		trayIcon->show() ;
-	}else{
-		ac->setChecked( false ) ;
-		trayIcon->hide() ;
+			return _show_tray() ;
+		}else{
+			utility::Task::suspendForOneSecond() ;
+		}
 	}
 
-	utility::changePathPermissions( f ) ;
-	utility::changePathOwner( f ) ;
+	/*
+	 * The tray doesnt seem to be ready yet but we cant wait any longer,just display it and
+	 * hope for the best.
+	 */
+	_show_tray() ;
 }
 
 void utility::trayProperty( QSystemTrayIcon * trayIcon,bool zuluCrypt )
 {
 	Q_UNUSED( zuluCrypt ) ;
 
-	QFile f( utility::homePath() + "/.zuluCrypt/tray" ) ;
+	if( _settings->contains( "ShowTrayIcon" ) ){
 
-	f.open( QIODevice::ReadOnly ) ;
+		if( _settings->value( "ShowTrayIcon" ).toBool() ){
 
-	char c ;
-
-	f.read( &c,1 ) ;
-
-	f.close() ;
-
-	f.open( QIODevice::WriteOnly | QIODevice::Truncate ) ;
-
-	if( c == '1' ){
-
-		f.write( "0" ) ;
-		trayIcon->hide() ;
-	}else{
-		f.write( "1" ) ;
-		trayIcon->show() ;
+			_settings->setValue( "ShowTrayIcon",false ) ;
+			trayIcon->hide() ;
+		}else{
+			_settings->setValue( "ShowTrayIcon",true ) ;
+			trayIcon->show() ;
+		}
 	}
-
-	utility::changePathPermissions( f ) ;
-	utility::changePathOwner( f ) ;
 }
 
 class translator
@@ -1999,11 +2088,6 @@ QStringList utility::directoryList( const QString& e )
 	return l ;
 }
 
-static QString _iconNamePath( const QString& app )
-{
-	return utility::homePath() + "/.zuluCrypt/" + app + ".iconName" ;
-}
-
 void utility::setIconMenu( const QString& app,QAction * ac,QWidget * w,
 			   std::function< void( const QString& ) >&& function )
 {
@@ -2015,16 +2099,12 @@ void utility::setIconMenu( const QString& app,QAction * ac,QWidget * w,
 
 		w->connect( m,SIGNAL( triggered( QAction * ) ),n,SLOT( selectOption( QAction * ) ) ) ;
 
-		if( !QFile::exists( _iconNamePath( app ) ) ){
+		if( !_settings->contains( "IconName" ) ){
 
-			utility::setIcons( app,app ) ;
+			_settings->setValue( "IconName",app ) ;
 		}
 
-		QFile f( _iconNamePath( app ) ) ;
-
-		f.open( QIODevice::ReadOnly ) ;
-
-		QString s = f.readAll() ;
+		QString s = _settings->value( "IconName" ).toString() ;
 
 		QDir d( INSTALL_PREFIX "/share/icons/hicolor/48x48/apps/" ) ;
 
@@ -2055,100 +2135,79 @@ void utility::setIconMenu( const QString& app,QAction * ac,QWidget * w,
 
 void utility::setIcons( const QString& app,const QString& iconName )
 {
-	QFile f( _iconNamePath( app ) ) ;
-
-	f.open( QIODevice::WriteOnly | QIODevice::Truncate ) ;
-
-	f.write( iconName.toLatin1() ) ;
-
-	utility::changePathOwner( f ) ;
-	utility::changePathPermissions( f ) ;
+	Q_UNUSED( app ) ;
+	_settings->setValue( "IconName",iconName ) ;
 }
 
 QIcon utility::getIcon( const QString& app )
 {
-	if( !QFile::exists( _iconNamePath( app ) ) ){
+	if( !_settings->contains( "IconName" ) ){
 
-		utility::setIcons( app,app ) ;
+		_settings->setValue( "IconName",app ) ;
 	}
 
-	QFile f( _iconNamePath( app ) ) ;
+	QString e = _settings->value( "IconName" ).toString() ;
 
-	if( f.open( QIODevice::ReadOnly ) ){
-
-		QString e = f.readAll() ;
-
-		if( e == "zuluCrypt" || e == "zuluMount" ){
-
-			QIcon icon( INSTALL_PREFIX "/share/icons/hicolor/48x48/apps/" + e + ".png" ) ;
-			return QIcon::fromTheme( app,icon ) ;
-		}else{
-			return QIcon( INSTALL_PREFIX "/share/icons/hicolor/48x48/apps/" + app + "." + e + ".png" ) ;
-		}
-	}else{
-		QIcon icon( INSTALL_PREFIX "/share/icons/hicolor/48x48/apps/" + app + ".png" ) ;
+	if( e == "zuluCrypt" || e == "zuluMount" ){
 
+		QIcon icon( INSTALL_PREFIX "/share/icons/hicolor/48x48/apps/" + e + ".png" ) ;
 		return QIcon::fromTheme( app,icon ) ;
+	}else{
+		return QIcon( INSTALL_PREFIX "/share/icons/hicolor/48x48/apps/" + app + "." + e + ".png" ) ;
 	}
 }
 
-static QString _veraCryptOptionPath( const QString& app )
-{
-	return utility::homePath() + "/.zuluCrypt/" + app + ".autoSetVolumeAsVeraCrypt" ;
-}
-
 bool utility::autoSetVolumeAsVeraCrypt( const QString& app )
 {
-	return utility::pathExists( _veraCryptOptionPath( app ) ) ;
+	Q_UNUSED( app ) ;
+
+	if( _settings->contains( "AutoSetVolumeAsVeraCrypt" ) ){
+
+		return _settings->value( "AutoSetVolumeAsVeraCrypt" ).toBool() ;
+	}else{
+		_settings->setValue( "AutoOpenFolderOnMount",false ) ;
+
+		return false ;
+	}
 }
 
 void utility::autoSetVolumeAsVeraCrypt( const QString& app,bool set )
 {
-	if( set ){
+	Q_UNUSED( app ) ;
 
-		QFile f( _veraCryptOptionPath( app ) ) ;
-		f.open( QIODevice::WriteOnly ) ;
-	}else{
-		QFile::remove( _veraCryptOptionPath( app ) ) ;
-	}
-}
-
-static QString _auto_open_config_path( const QString& app )
-{
-	return utility::homePath() + "/.zuluCrypt/" + app + "-gui.NoAutoOpenFolder" ;
+	_settings->setValue( "AutoSetVolumeAsVeraCrypt",set ) ;
 }
 
 void utility::autoOpenFolderOnMount( const QString& app,bool e )
 {
-	auto x = _auto_open_config_path( app ) ;
-
-	if( e ){
-
-		QFile::remove( x ) ;
-	}else{
-		QFile( x ).open( QIODevice::WriteOnly ) ;
-	}
+	Q_UNUSED( app ) ;
+	_settings->setValue( "AutoOpenFolderOnMount",e ) ;
 }
 
 bool utility::autoOpenFolderOnMount( const QString& app )
 {
-	return !QFile::exists( _auto_open_config_path( app ) ) ;
+	Q_UNUSED( app ) ;
+
+	if( _settings->contains( "AutoOpenFolderOnMount" ) ){
+
+		return _settings->value( "AutoOpenFolderOnMount" ).toBool() ;
+	}else{
+		_settings->setValue( "AutoOpenFolderOnMount",true ) ;
+
+		return true ;
+	}
 }
 
 QString utility::powerOffCommand()
 {
-	QFile f( utility::homePath() + "/.zuluCrypt/power-off-command" ) ;
+	if( _settings->contains( "PowerOffCommand" ) ){
 
-	QString e ;
+		return _settings->value( "PowerOffCommand" ).toString() ;
+	}else{
+		_settings->setValue( "PowerOffCommand","" ) ;
 
-	if( f.open( QIODevice::ReadOnly ) ){
-
-		e = f.readAll() ;
-
-		e.remove( '\n' ) ;
+		return QString() ;
 	}
-
-	return e ;
 }
 
 QString utility::prettyfySpaceUsage( quint64 s )
@@ -2186,88 +2245,64 @@ QString utility::prettyfySpaceUsage( quint64 s )
 	}
 }
 
-void utility::createHomeFolder()
-{
-	utility::createFolderPath( utility::homePath() + "/.zuluCrypt/" ) ;
-}
-
-void utility::createFolderPath( const QString& e )
-{
-	QDir().mkdir( e ) ;
-
-	utility::changePathOwner( e ) ;
-	utility::changePathPermissions( e,0777 ) ;
-}
-
 QStringList utility::plainDmCryptOptions()
 {
-	const QByteArray _options = R"(aes.cbc-essiv:sha256.256.ripemd160
-aes.cbc-essiv:sha256.256.sha256
-aes.cbc-essiv:sha256.256.sha512
-aes.cbc-essiv:sha256.256.sha1
-aes.cbc-essiv:sha256.512.ripemd160
-aes.cbc-essiv:sha256.512.sha256
-aes.cbc-essiv:sha256.512.sha512
-aes.cbc-essiv:sha256.512.sha1
-aes.xts-plain64.256.ripemd160
-aes.xts-plain64.256.sha256
-aes.xts-plain64.256.sha512
-aes.xts-plain64.256.sha1
-aes.xts-plain64.512.ripemd160
-aes.xts-plain64.512.sha256
-aes.xts-plain64.512.sha512
-aes.xts-plain64.512.sha1)" ;
+	if( _settings->contains( "PlainDmCryptOptions" ) ){
 
-	QFile f( utility::homePath() + "/.zuluCrypt/plainDmCryptOptions" ) ;
+		return _settings->value( "PlainDmCryptOptions" ).toStringList() ;
+	}else{
+		QStringList s = {
 
-	if( !f.exists() ){
+			{ "aes.cbc-essiv:sha256.256.sha256" },
+			{ "aes.cbc-essiv:sha256.256.sha512" },
+			{ "aes.cbc-essiv:sha256.256.sha1" },
+			{ "aes.cbc-essiv:sha256.512.ripemd160" },
+			{ "aes.cbc-essiv:sha256.512.sha256" },
+			{ "aes.cbc-essiv:sha256.512.sha512" },
+			{ "aes.cbc-essiv:sha256.512.sha1" },
+			{ "aes.xts-plain64.256.ripemd160" },
+			{ "aes.xts-plain64.256.sha256" },
+			{ "aes.xts-plain64.256.sha512" },
+			{ "aes.xts-plain64.256.sha512" },
+			{ "aes.xts-plain64.256.sha1" },
+			{ "aes.xts-plain64.256.sha1" },
+			{ "aes.xts-plain64.512.ripemd160" },
+			{ "aes.xts-plain64.512.sha256" },
+			{ "aes.xts-plain64.512.sha512" },
+			{ "aes.xts-plain64.512.sha1" }
+		};
 
-		if( f.open( QIODevice::WriteOnly ) ){
+		_settings->setValue( "PlainDmCryptOptions",s ) ;
 
-			f.write( _options ) ;
-
-			utility::changePathOwner( f ) ;
-			utility::changePathPermissions( f,0666 ) ;
-
-			f.close() ;
-		}
+		return s ;
 	}
-
-	if( f.open( QIODevice::ReadOnly ) ){
-
-		return utility::split( f.readAll() ) ;
-	}
-
-	return QStringList() ;
 }
 
 QStringList utility::supportedFileSystems()
 {
-	QFile f( utility::homePath() + "/.zuluCrypt/supportedFileSystems" ) ;
+	if( _settings->contains( "SupportedFileSystems" ) ){
 
-	if( !f.exists() ){
+		return _settings->value( "SupportedFileSystems" ).toStringList() ;
+	}else{
+		QStringList s{ "ext4","vfat","ntfs","ext2","ext3","exfat","ntfs","btrfs" } ;
 
-		if( f.open( QIODevice::WriteOnly ) ){
+		_settings->setValue( "SupportedFileSystems",s ) ;
 
-			f.write( "ext4\nvfat\nntfs\next2\next3\nexfat\nbtrfs" ) ;
-
-			utility::changePathOwner( f ) ;
-			utility::changePathPermissions( f,0666 ) ;
-
-			f.close() ;
-		}
+		return s ;
 	}
-
-	if( f.open( QIODevice::ReadOnly ) ){
-
-		return utility::split( f.readAll() ) ;
-	}
-
-	return { "ext4","vfat","ntfs","ext2","ext3","exfat","btrfs" } ;
 }
 
 std::pair< bool,QByteArray > utility::getKeyFromNetwork( const QString& e )
 {
+	Q_UNUSED( e ) ;
+
+	return { false,QByteArray() } ;
+#if 0
+	if( !_settings->contains( "NetworkAddress" ) ){
+
+		return _settings->setValue( "NetworkAddress","127.0.0.1" ) ;
+	}
+
 	QFile f( utility::homePath() + "/.zuluCrypt/network" ) ;
 
 	if( !f.open( QIODevice::ReadOnly ) ){
@@ -2310,6 +2345,7 @@ std::pair< bool,QByteArray > utility::getKeyFromNetwork( const QString& e )
 	}else{
 		return { false,"" } ;
 	}
+#endif
 }
 
 void utility::setHDPI( const QString& e )
@@ -2320,19 +2356,12 @@ void utility::setHDPI( const QString& e )
 
 	QApplication::setAttribute( Qt::AA_EnableHighDpiScaling ) ;
 
-	QFile f( utility::homePath() + "/.zuluCrypt/" + e + ".scaleFactor" ) ;
+	if( !_settings->contains( "ScaleFactor" ) ){
 
-	if( !f.exists() ){
-
-		f.open( QIODevice::WriteOnly ) ;
-		f.write( "1" ) ;
-		f.close() ;
+		_settings->setValue( "ScaleFactor","1" ) ;
 	}
 
-	if( f.open( QIODevice::ReadOnly ) ){
-
-		qputenv( "QT_SCALE_FACTOR",f.readAll().replace( "\n","" ) ) ;
-	}
+	qputenv( "QT_SCALE_FACTOR",_settings->value( "ScaleFactor" ).toString().toLatin1() ) ;
 #endif
 }
 
@@ -2417,36 +2446,23 @@ QString utility::readPassword( bool addNewLine )
 
 QString utility::fileManager()
 {
-	QFile f( utility::homePath() + "/.zuluCrypt/FileManager" ) ;
+	if( _settings->contains( "FileManager" ) ){
 
-	if( !f.exists() ){
-
-		f.open( QIODevice::WriteOnly | QIODevice::Truncate ) ;
-
-		f.write( "xdg-open" ) ;
-
-		f.close() ;
-	}
-
-	if( !f.open( QIODevice::ReadOnly ) ){
+		return _settings->value( "FileManager" ).toString() ;
+	}else{
+		_settings->setValue( "FileManager","xdg-open" ) ;
 
 		return "xdg-open" ;
-	}else{
-		return utility::split( f.readAll() ).first() ;
 	}
 }
 
 void utility::setFileManager( const QString& e )
 {
-	QFile f( utility::homePath() + "/.zuluCrypt/FileManager" ) ;
-
-	f.open( QIODevice::WriteOnly | QIODevice::Truncate ) ;
-
 	if( e.isEmpty() ){
 
-		f.write( "xdg-open" ) ;
+		_settings->setValue( "FileManager","xdg-open" ) ;
 	}else{
-		f.write( e.toLatin1() ) ;
+		_settings->setValue( "FileManager",e ) ;
 	}
 }
 
@@ -2454,6 +2470,8 @@ QProcessEnvironment utility::systemEnvironment()
 {
 	auto e = QProcessEnvironment::systemEnvironment() ;
 
+	e.insert( "zuluCryptRuntimePath",utility::passwordSocketPath() + "/" ) ;
+
 	e.insert( "CRYFS_NO_UPDATE_CHECK","TRUE" ) ;
 	e.insert( "CRYFS_FRONTEND","noninteractive" ) ;
 
@@ -2463,3 +2481,54 @@ QProcessEnvironment utility::systemEnvironment()
 
 	return e ;
 }
+
+bool utility::clearPassword()
+{
+	if( _settings->contains( "ClearPassword" ) ){
+
+		return _settings->value( "ClearPassword" ).toBool() ;
+	}else{
+		_settings->setValue( "ClearPassword",true ) ;
+
+		return true ;
+	}
+}
+
+bool utility::readOnlyOption()
+{
+	if( _settings->contains( "ReadOnly" ) ){
+
+		return _settings->value( "ReadOnly" ).toBool() ;
+	}else{
+		_settings->setValue( "ReadOnly",false ) ;
+
+		return false ;
+	}
+}
+
+void utility::readOnlyOption( bool e )
+{
+	_settings->setValue( "ReadOnly",e ) ;
+}
+
+bool utility::readOnlyWarning()
+{
+	if( _settings->contains( "ReadOnlyWarning" ) ){
+
+		return _settings->value( "ReadOnlyWarning" ).toBool() ;
+	}else{
+		_settings->setValue( "ReadOnlyWarning",true ) ;
+
+		return true ;
+	}
+}
+
+void utility::readOnlyWarning( bool e )
+{
+	_settings->setValue( "ReadOnlyWarning",e ) ;
+}
+
+QString utility::failedToStartzuluPolkit()
+{
+	return QObject::tr( "Failed To Start Helper Application.\n\n\"org.zulucrypt.zulupolkit.policy\" polkit file is misconfigured,\nzuluPolkit executable could not be found\n or pkexec failed to start zuluPolkit." ) ;
+}
