@@ -20,6 +20,7 @@
 #ifndef MISCFUNCTIONS_H
 #define MISCFUNCTIONS_H
 
+#include <QSettings>
 #include <QString>
 #include <QStringList>
 #include <QEvent>
@@ -64,6 +65,30 @@
 #include <iostream>
 #include <atomic>
 
+namespace utility
+{
+	class raii
+	{
+	public:
+		raii( std::function< void() > s ) : m_function( std::move( s ) )
+		{
+		}
+		~raii()
+		{
+			if( m_run ){
+
+				m_function() ;
+			}
+		}
+		void cancel()
+		{
+			m_run = false ;
+		}
+	private:
+		bool m_run = true ;
+		std::function< void() > m_function ;
+	};
+}
 namespace utility
 {
 	class debug
@@ -179,8 +204,6 @@ namespace utility
 
 namespace utility
 {
-	void setUID( int ) ;
-
 	int getUID() ;
 	int getUserID() ;
 	int getGUID( int uid ) ;
@@ -262,6 +285,18 @@ namespace utility
 
 	QProcessEnvironment systemEnvironment() ;
 
+	enum class background_thread{ True,False } ;
+
+	bool requireSystemPermissions( const QString&,utility::background_thread = utility::background_thread::False ) ;
+	bool enablePolkit( utility::background_thread ) ;
+
+	void setSettingsObject( QSettings * ) ;
+	QSettings& settingsObject() ;
+
+	void setDefaultEnvironment() ;
+	QString passwordSocketPath() ;
+	QString socketPath() ;
+	bool clearPassword() ;
 	bool userBelongsToGroup( const char * groupname ) ;
 	bool runningInMixedMode( void ) ;
 	bool notRunningInMixedMode( void ) ;
@@ -277,6 +312,7 @@ namespace utility
 	void dropPrivileges( int = -1 ) ;
 	QString fileManager( void ) ;
 	void setFileManager( const QString& ) ;
+	QString failedToStartzuluPolkit() ;
 	QString prettyfySpaceUsage( quint64 ) ;
 	QString resolvePath( const QString& ) ;
 	QString hashPath( const QByteArray& ) ;
@@ -316,10 +352,8 @@ namespace utility
 	QStringList supportedFileSystems( void ) ;
 	bool userHasGoodVersionOfWhirlpool( void ) ;
 	void licenseInfo( QWidget * ) ;
-	void showTrayIcon( QAction *,QSystemTrayIcon *,bool = true ) ;
+	void showTrayIcon( QAction *,QObject * obj,bool = true ) ;
 	void trayProperty( QSystemTrayIcon *,bool = true ) ;
-	void createHomeFolder( void ) ;
-	void createFolderPath( const QString& ) ;
 	bool platformIsLinux( void ) ;
 	bool platformIsOSX( void ) ;
 	QStringList executableSearchPaths( void ) ;
@@ -337,6 +371,14 @@ namespace utility
 	bool reUseMountPointPath( void ) ;
 	bool reUseMountPoint( void ) ;
 
+	bool readOnlyOption( void ) ;
+	void readOnlyOption( bool ) ;
+
+	bool readOnlyWarning( void ) ;
+	void readOnlyWarning( bool ) ;
+
+	void polkitFailedWarning( std::function< void() > ) ;
+
 	void setLocalizationLanguage( bool translate,QMenu * ac,const QString& ) ;
 	void languageMenu( QWidget *,QMenu *,QAction *,const char * ) ;
 
@@ -349,6 +391,9 @@ namespace utility
 
 	int pluginKey( QWidget *,QByteArray *,const QString& ) ;
 
+	std::pair< bool,QByteArray > privilegedReadConfigFile( const QString& ) ;
+	void privilegedWriteConfigFile( const QByteArray&,const QString& ) ;
+
 	QFont getFont( QWidget * ) ;
 	void saveFont( const QFont& ) ;
 
@@ -579,13 +624,14 @@ namespace utility
 	class Task
 	{
 	public :
-		static ::Task::future< utility::Task >& run( const QString& exe,bool e ) ;
+		enum class USEPOLKIT{ True,False } ;
+		static ::Task::future< utility::Task >& run( const QString& exe,USEPOLKIT e ) ;
 
-		static ::Task::future< utility::Task >& run( const QString& exe,int,bool e ) ;
+		static ::Task::future< utility::Task >& run( const QString& exe,int,USEPOLKIT e ) ;
 
 		static ::Task::future< utility::Task >& run( const QString& exe )
 		{
-			return ::Task::run< utility::Task >( [ exe ](){ return utility::Task( exe ) ; } ) ;
+			return ::Task::run( [ exe ](){ return utility::Task( exe ) ; } ) ;
 		}
 		static void wait( int s )
 		{
@@ -624,12 +670,12 @@ namespace utility
 		Task()
 		{
 		}
-		Task( const QString& exe,int waitTime = -1,const QProcessEnvironment& env = QProcessEnvironment(),
-		      const QByteArray& password = QByteArray(),const std::function< void() >& f = [](){},bool e = true )
+		Task( const QString& exe,int waitTime = -1,const QProcessEnvironment& env = utility::systemEnvironment(),
+		      const QByteArray& password = QByteArray(),const std::function< void() >& f = [](){},USEPOLKIT e = USEPOLKIT::True )
 		{
 			this->execute( exe,waitTime,env,password,f,e ) ;
 		}
-		Task( const QString& exe,const QProcessEnvironment& env,const std::function< void() >& f,bool e = true )
+		Task( const QString& exe,const QProcessEnvironment& env,const std::function< void() >& f,USEPOLKIT e = USEPOLKIT::True )
 		{
 			this->execute( exe,-1,env,QByteArray(),f,e ) ;
 		}
@@ -675,7 +721,7 @@ namespace utility
 		}	
 	private:
 		void execute( const QString& exe,int waitTime,const QProcessEnvironment& env,
-			      const QByteArray& password,const std::function< void() >& f,bool ) ;
+			      const QByteArray& password,const std::function< void() >& f,USEPOLKIT ) ;
 		QByteArray m_stdOut ;
 		QByteArray m_stdError ;
 
