@@ -66,7 +66,8 @@
 #include "tablewidget.h"
 #include "utility.h"
 #include "task.h"
-#include "contactinfo.h"
+#include "about.h"
+#include "help.h"
 
 #include "veracrypt_support.h"
 #include "pdf_path.h"
@@ -77,7 +78,8 @@
 
 zuluCrypt::zuluCrypt( QWidget * parent ) :
 	QMainWindow( parent ),
-	m_mountInfo( monitor_mountinfo::instance( this,false,[ this ](){ this->quitApplication() ; } ) )
+	m_mountInfo( this,false,[ this ](){ this->quitApplication() ; } ),
+	m_checkForUpdates( this )
 {
 }
 
@@ -110,25 +112,23 @@ void zuluCrypt::helperStarted( bool e,const QString& volume )
 		this->setupConnections() ;
 		this->initFont() ;
 		this->initKeyCombo() ;
-		this->initTray() ;
+		this->initTray( m_startHidden ) ;
 		this->info() ;
 		this->autoUpdateCheck() ;
 		this->setLocalizationLanguage( false ) ;
 		this->updateVolumeList( volume ) ;
 
-		m_mountInfo->start() ;
+		m_mountInfo.start() ;
 
-		if( m_startHidden ){
+		if( !m_startHidden ){
 
-			m_trayIcon.show() ;
-		}else{
 			this->setVisible( true ) ;
 			this->show() ;
 			this->raise() ;
 			this->setWindowState( Qt::WindowActive ) ;
 		}
 	}else{
-		DialogMsg( this ).ShowUIOK( tr( "ERROR" ),tr( "Failed To Start Helper Application.\n\"org.zulucrypt.zulupolkit.policy\" polkit file is either misconfigured or zuluPolkit executable could not be found." ) ) ;
+		DialogMsg( this ).ShowUIOK( tr( "ERROR" ),utility::failedToStartzuluPolkit() ) ;
 
 		this->closeApplication() ;
 	}
@@ -226,6 +226,11 @@ void zuluCrypt::raiseWindow( const QString& device )
 	}
 }
 
+void zuluCrypt::polkitFailedWarning()
+{
+	DialogMsg( this ).ShowUIOK( tr( "ERROR" ),tr( "zuluCrypt Failed To Connect To zuluPolkit.\nPlease Report This Serious Bug." ) ) ;
+}
+
 void zuluCrypt::start()
 {
 	/*
@@ -241,23 +246,18 @@ void zuluCrypt::start()
 	m_openPath     = utility::cmdArgumentValue( l,"-m",utility::fileManager() ) ;
 	m_startHidden  = l.contains( "-e" ) ;
 
-	if( utility::useZuluPolkit() ){
-
-		utility::setUID( getuid() ) ;
-	}else{
-		utility::setUID( utility::cmdArgumentValue( l,"-K","-1" ).toInt() ) ;
-	}
-
-	auto s = utility::homePath() + "/.zuluCrypt-socket" ;
-
-	utility::createHomeFolder() ;
-	utility::createFolderPath( s ) ;
+	auto s = utility::socketPath() ;
 
 	if( utility::configDirectoriesAreNotWritable( this ) ){
 
 		return this->closeApplication() ;
 	}
 
+	utility::polkitFailedWarning( [ this ](){
+
+		QMetaObject::invokeMethod( this,"polkitFailedWarning",Qt::QueuedConnection ) ;
+	} ) ;
+
 	oneinstance::instance( this,
 			       s + "/zuluCrypt-gui.socket",
 			       utility::cmdArgumentValue( l,"-d" ),
@@ -269,7 +269,7 @@ void zuluCrypt::start()
 			       [ this ]( const QString& e ){ this->raiseWindow( e ) ; } ) ;
 }
 
-void zuluCrypt::initTray()
+void zuluCrypt::initTray( bool e )
 {
 	utility::setIconMenu( "zuluCrypt",m_ui->actionSelect_Icons,this,[ this ]( const QString& e ){
 
@@ -280,7 +280,16 @@ void zuluCrypt::initTray()
 
 	this->setIcons() ;
 
-	utility::showTrayIcon( m_ui->actionTray_icon,&m_trayIcon ) ;
+	utility::showTrayIcon( m_ui->actionTray_icon,this,e ) ;
+}
+
+void zuluCrypt::showTrayIcon( bool e )
+{
+	if( e ){
+		m_trayIcon.show() ;
+	}else{
+		m_trayIcon.hide() ;
+	}
 }
 
 void zuluCrypt::trayProperty()
@@ -373,7 +382,6 @@ void zuluCrypt::setupConnections()
 	connect( m_ui->actionClose_all_opened_volumes,SIGNAL( triggered() ),this,SLOT( closeAllVolumes() ) ) ;
 	connect( m_ui->actionEncrypt_file,SIGNAL( triggered() ),this,SLOT( encryptFile() ) ) ;
 	connect( m_ui->actionDecrypt_file,SIGNAL( triggered() ),this,SLOT( decryptFile() ) ) ;
-	connect( m_ui->actionLuks_header_backup,SIGNAL( triggered() ),this,SLOT( HelpLuksHeaderBackUp() ) ) ;
 	connect( m_ui->actionManage_system_partitions,SIGNAL( triggered() ),this,SLOT( ShowManageSystemPartitions() ) ) ;
 	connect( m_ui->actionManage_non_system_partitions,SIGNAL( triggered() ),this,SLOT( ShowManageNonSystemPartitions() ) ) ;
 	connect( m_ui->actionChange_internal_wallet_password,SIGNAL( triggered() ),this,SLOT( changePassWordOfInternalWallet() ) ) ;
@@ -382,7 +390,6 @@ void zuluCrypt::setupConnections()
 	connect( m_ui->actionManage_volumes_in_internal_wallet,SIGNAL( triggered() ),this,SLOT( manageVolumesInInternalWallet() ) ) ;
 	connect( m_ui->actionOpen_zuluCrypt_pdf,SIGNAL( triggered() ),this,SLOT( openpdf() ) ) ;
 	connect( m_ui->actionCheck_For_Update,SIGNAL( triggered() ),this,SLOT( updateCheck() ) ) ;
-	connect( m_ui->actionContact_Info,SIGNAL( triggered() ),this,SLOT( cinfo() ) ) ;
 	connect( m_ui->actionSet_File_Manager,SIGNAL( triggered() ),this,SLOT( setFileManager() ) ) ;
 
 	connect( this,SIGNAL( closeVolume( QTableWidgetItem *,int ) ),this,SLOT( closeAll( QTableWidgetItem *,int ) ) ) ;
@@ -410,7 +417,7 @@ void zuluCrypt::setupConnections()
 
 	connect( m_ui->menuOptions,SIGNAL( aboutToShow() ),this,SLOT( optionMenuAboutToShow() ) ) ;
 
-	connect( m_mountInfo.get(),SIGNAL( gotEvent() ),this,SLOT( updateVolumeList() ) ) ;
+	connect( &m_mountInfo,SIGNAL( gotEvent() ),this,SLOT( updateVolumeList() ) ) ;
 
 	m_language_menu = [ this ](){
 
@@ -424,9 +431,6 @@ void zuluCrypt::setupConnections()
 		return m ;
 	}() ;
 
-	m_ui->actionManage_system_partitions->setEnabled( utility::userIsRoot() ) ;
-	m_ui->actionManage_non_system_partitions->setEnabled( utility::userIsRoot() ) ;
-
 	m_ui->actionVeracrypt_container_in_a_file->setEnabled( true ) ;
 	m_ui->actionVeracrypt_container_in_a_partition->setEnabled( true ) ;
 
@@ -456,22 +460,21 @@ void zuluCrypt::optionMenuAboutToShow()
 
 void zuluCrypt::updateCheck()
 {
-	checkForUpdates::instance( this ) ;
+	m_checkForUpdates.run() ;
 }
 
 void zuluCrypt::cinfo()
 {
-	contactInfo::instance( this ) ;
 }
 
 void zuluCrypt::autoUpdateCheck()
 {
-	checkForUpdates::instance( this,"zuluCrypt" ) ;
+	m_checkForUpdates.run( "zuluCrypt" ) ;
 }
 
 void zuluCrypt::info()
 {
-	cryptoinfo::instance( this,utility::homePath() + "/.zuluCrypt/doNotshowWarning.option",QString() ) ;
+	//cryptoinfo::instance( this,utility::homePath() + "/.zuluCrypt/doNotshowWarning.option",QString() ) ;
 }
 
 static void _walletconfig( QWidget * widget,secrets& s,LXQt::Wallet::BackEnd e )
@@ -516,35 +519,12 @@ void zuluCrypt::permissionExplanation()
 
 void zuluCrypt::ShowManageSystemPartitions()
 {
-	QDir d ;
-	QFile f ;
-
-	/*
-	 * move config files to /etc/zuluCrypt/
-	 */
-	d.mkdir( "/etc/zuluCrypt" ) ;
-	f.rename( "/etc/zuluCrypt-system","/etc/zuluCrypt/system_volumes.list" ) ;
-
-	f.rename( "/etc/zuluCrypt-nonsystem","/etc/zuluCrypt/nonsystem_volumes.list" ) ;
-
-	manageSystemVolumes::instance( this ).ShowUI( "/etc/zuluCrypt/system_volumes.list" ) ;
+	manageSystemVolumes::instance( this,"/etc/zuluCrypt/system_volumes.list" ) ;
 }
 
 void zuluCrypt::ShowManageNonSystemPartitions()
 {
-	QDir d ;
-	QFile f ;
-
-	/*
-	 * move config files to /etc/zuluCrypt/
-	 */
-
-	d.mkdir( "/etc/zuluCrypt" ) ;
-	f.rename( "/etc/zuluCrypt-system","/etc/zuluCrypt/system_volumes.list" ) ;
-
-	f.rename( "/etc/zuluCrypt-nonsystem","/etc/zuluCrypt/nonsystem_volumes.list" ) ;
-
-	manageSystemVolumes::instance( this ).ShowUI( "/etc/zuluCrypt/nonsystem_volumes.list" ) ;
+	manageSystemVolumes::instance( this,"/etc/zuluCrypt/nonsystem_volumes.list" ) ;
 }
 
 void zuluCrypt::currentItemChanged( QTableWidgetItem * current,QTableWidgetItem * previous )
@@ -563,7 +543,7 @@ void zuluCrypt::closeAllVolumes()
 {
 	m_ui->tableWidget->setEnabled( false ) ;
 
-	m_mountInfo->announceEvents( false ) ;
+	m_mountInfo.announceEvents( false ) ;
 
 	Task::await( [ this ](){
 
@@ -602,7 +582,7 @@ void zuluCrypt::closeAllVolumes()
 
 	} ) ;
 
-	m_mountInfo->announceEvents( true ) ;
+	m_mountInfo.announceEvents( true ) ;
 
 	m_ui->tableWidget->setEnabled( true ) ;
 }
@@ -676,13 +656,13 @@ void zuluCrypt::quitApplication()
 void zuluCrypt::closeApplication()
 {
 	utility::quitHelper() ;
-	m_mountInfo->stop()() ;
+	m_mountInfo.stop()() ;
 }
 
 void zuluCrypt::closeApplication( int s )
 {
 	Q_UNUSED( s ) ;
-	m_mountInfo->stop()() ;
+	m_mountInfo.stop()() ;
 }
 
 void zuluCrypt::trayClicked( QSystemTrayIcon::ActivationReason e )
@@ -763,7 +743,6 @@ void zuluCrypt::setUserFont( QFont Font )
 	m_ui->actionVeracrypt_container_in_a_partition->setFont( Font ) ;
 	m_ui->actionOpen_zuluCrypt_pdf->setFont( Font ) ;
 	m_ui->actionCheck_For_Update->setFont( Font ) ;
-	m_ui->actionContact_Info->setFont( Font ) ;
 	m_ui->actionSelect_Language->setFont( Font ) ;
 	m_ui->actionAuto_Open_Mount_Point->setFont( Font ) ;
 	m_ui->actionSelect_Icons->setFont( Font ) ;
@@ -771,7 +750,7 @@ void zuluCrypt::setUserFont( QFont Font )
 
 void zuluCrypt::aboutMenuOption( void )
 {
-	utility::licenseInfo( this ) ;
+	about::instance( this ) ;
 }
 
 void zuluCrypt::HelpLuksHeaderBackUp()
@@ -803,7 +782,7 @@ void zuluCrypt::volume_property()
 
 	x.replace( "\"","\"\"\"" ) ;
 
-	Task::run<QString>( [ x ](){
+	Task::run( [ x ](){
 
 		auto e = utility::appendUserUID( "%1 -s -d \"%2\"" ) ;
 
@@ -922,24 +901,7 @@ void zuluCrypt::openFolder( const QString& path )
 
 void zuluCrypt::openpdf()
 {
-	auto x = tr( "WARNING!" ) ;
-	auto y = tr( "Failed to open zuluCrypt.pdf,make sure your system can open pdf files using \"%1\" tool and try again" ).arg( m_openPath ) ;
-
-	QString e = PDF_PATH ;
-
-	if( utility::pathExists( e ) ){
-
-		utility::openPath( e,m_openPath,this,x,y ) ;
-	}else{
-		e += ".gz" ;
-
-		if( utility::pathExists( e ) ){
-
-			utility::openPath( e,m_openPath,this,x,y ) ;
-		}else{
-			utility::openPath( PDF_PATH,m_openPath,this,x,y ) ;
-		}
-	}
+	help::instance( this,m_openPath ) ;
 }
 
 void zuluCrypt::itemClicked( QTableWidgetItem * it )
@@ -1164,7 +1126,7 @@ void zuluCrypt::ShowCreateFile()
 
 void zuluCrypt::ShowNonSystemPartitions()
 {
-	openvolume::instance( this ).ShowNonSystemPartitions( [ this ]( const QString& e ){
+	openvolume::instance( this,false ).ShowNonSystemPartitions( [ this ]( const QString& e ){
 
 		createvolume::instance( this ).ShowPartition( e ) ;
 	} ) ;
@@ -1172,7 +1134,7 @@ void zuluCrypt::ShowNonSystemPartitions()
 
 void zuluCrypt::ShowOpenPartition()
 {
-	openvolume::instance( this ).showEncryptedOnly().ShowAllPartitions( [ this ]( const QString& e ){
+	openvolume::instance( this,true ).showEncryptedOnly().ShowAllPartitions( [ this ]( const QString& e ){
 
 		this->setUpPasswordDialog().ShowUI( e ) ;
 	} ) ;
