@@ -29,6 +29,7 @@
 #include "lxqt_wallet.h"
 #include "utility.h"
 #include "secrets.h"
+#include "checkforupdates.h"
 
 class QWidget ;
 class QTableWidgetItem ;
@@ -65,6 +66,8 @@ signals:
 	void closeVolume( QTableWidgetItem *,int ) ;
 	void updateVolumeListSignal( QString,QString ) ;
 private slots :
+	void showTrayIcon( bool ) ;
+	void polkitFailedWarning( void ) ;
 	void setFileManager( void ) ;
 	void helperStarted( bool,const QString& ) ;
 	void start( void ) ;
@@ -147,7 +150,7 @@ private:
 	void setupUIElements( void ) ;
 	void closeEvent( QCloseEvent * ) ;
 	void setUserFont( QFont ) ;
-	void initTray( void ) ;
+	void initTray( bool ) ;
 	void initFont( void ) ;
 	void initKeyCombo( void ) ;
 	void closeStatusErrorMessage( int ) ;
@@ -167,7 +170,8 @@ private:
 	bool m_startHidden ;
 	int m_userID ;
 	bool m_autoOpenMountPoint ;
-	std::unique_ptr< monitor_mountinfo > m_mountInfo ;
+	monitor_mountinfo m_mountInfo ;
+	checkForUpdates m_checkForUpdates ;
 };
 
 #endif // ZULUCRYPT_H
