@@ -547,6 +547,16 @@ void keyDialog::encryptedFolderMount()
 		msg.ShowUIOK( tr( "ERROR" ),tr( "Failed to unlock the volume.\nNot supported volume encountered" ) ) ;
 		break;
 
+	case siritask::status::ecrypfsBadExePermissions :
+
+		msg.ShowUIOK( tr( "ERROR" ),tr( "This backend requires root's privileges and an attempt to acquire them has failed." ) ) ;
+		break;
+
+	case siritask::status::cryfsMigrateFileSystem :
+
+		msg.ShowUIOK( tr( "ERROR" ),tr( "zuluMount Can Not Unlock This Volume Because Its FileSystem Has To Manually Be Converted To The Version Of Cryfs That Is Currently In Use.\n\nRun Cryfs With This Volume To Manually Update This Volume's FileSystem." ) ) ;
+		break;
+
 	case siritask::status::backendFail :
 	default:
 
@@ -854,7 +864,10 @@ void keyDialog::openVolume()
 
 			if( m_ui->cbKeyType->currentIndex() == keyDialog::Key ){
 
-				m_ui->lineEditKey->clear() ;
+				if( utility::clearPassword() ){
+
+					m_ui->lineEditKey->clear() ;
+				}
 			}
 
 			this->enableAll() ;
