@@ -36,14 +36,6 @@ class monitor_mountinfo : public QObject
 {
 	Q_OBJECT
 public:
-	static std::unique_ptr< monitor_mountinfo > instance( QObject * parent,
-							     bool b,
-							     std::function< void() > f )
-	{
-		return std::unique_ptr< monitor_mountinfo >( new monitor_mountinfo( parent,
-										    b,
-										    std::move( f ) ) ) ;
-	}
 	monitor_mountinfo( QObject * parent,bool,std::function< void() > ) ;
 	std::function< void() > stop() ;
 	void announceEvents( bool ) ;
