@@ -45,7 +45,6 @@ static bool _delete_folder( const QString& m )
 static bool _create_folder( const QString& m )
 {
 	return _m( QString( "%1 -B %2" ).arg( zuluMountPath,m ) ) ;
-
 }
 
 template< typename ... T >
@@ -67,6 +66,17 @@ static bool _ecryptfs( const T& e )
 	return utility::equalsAtleastOne( e,"ecryptfs","ecryptfs-simple" ) ;
 }
 
+template< typename T >
+static utility::Task::USEPOLKIT _ecryptfs_1( const T& e )
+{
+	if( _ecryptfs( e ) ){
+
+		return utility::Task::USEPOLKIT::True ;
+	}else{
+		return utility::Task::USEPOLKIT::False ;
+	}
+}
+
 static bool _ecryptfs_illegal_path( const siritask::options& opts )
 {
 	if( _ecryptfs( opts.type ) && utility::useZuluPolkit() ){
@@ -103,41 +113,76 @@ Task::future< bool >& siritask::encryptedFolderUnMount( const QString& cipherFol
 							const QString& mountPoint,
 							const QString& fileSystem )
 {
-	return Task::run< bool >( [ = ](){
+	return Task::run( [ = ](){
+
+		auto ecryptfs = _ecryptfs( fileSystem ) ;
 
 		auto cmd = [ & ](){
 
-			if( _ecryptfs( fileSystem ) ){
+			if( ecryptfs ){
 
 				auto exe = utility::executableFullPath( "ecryptfs-simple" ) ;
 
 				auto s = exe + " -k " + _makePath( cipherFolder ) ;
 
-				if( utility::runningInMixedMode() ){
+				if( utility::useZuluPolkit() ){
 
 					return _wrap_su( s ) ;
 				}else{
 					return s ;
 				}
 			}else{
-				if( utility::platformIsLinux() ){
+				if( utility::platformIsOSX() ){
 
-					return "fusermount -u " + _makePath( mountPoint ) ;
-				}else{
 					return "umount " + _makePath( mountPoint ) ;
+				}else{
+					return "fusermount -u " + _makePath( mountPoint ) ;
 				}
 			}
-		}() ;
+		} ;
 
-		utility::Task::waitForOneSecond() ;
+		const int max_count = 5 ;
 
-		for( int i = 0 ; i < 5 ; i++ ){
+		if( ecryptfs ){
 
-			if( utility::Task::run( cmd,10000,_ecryptfs( fileSystem ) ).get().success() ){
+			bool not_set = true ;
 
-				return true ;
-			}else{
-				utility::Task::waitForOneSecond() ;
+			auto exe = cmd() ;
+
+			for( int i = 0 ; i < max_count ; i++ ){
+
+				auto s = utility::Task::run( exe,10000,utility::Task::USEPOLKIT::True ).get() ;
+
+				if( s.success() ){
+
+					return true ;
+				}else{
+					if( not_set && s.stdError().contains( "error: failed to set gid" ) ){
+
+						if( utility::enablePolkit( utility::background_thread::True ) ){
+
+							not_set = false ;
+
+							exe = cmd() ;
+						}else{
+							return false ;
+						}
+					}else{
+						utility::Task::waitForOneSecond() ;
+					}
+				}
+			}
+		}else{
+			for( int i = 0 ; i < max_count ; i++ ){
+
+				auto s = utility::Task::run( cmd(),10000,utility::Task::USEPOLKIT::False ).get() ;
+
+				if( s.success() ){
+
+					return true ;
+				}else{
+					utility::Task::waitForOneSecond() ;
+				}
 			}
 		}
 
@@ -219,10 +264,7 @@ static QString _args( const QString& exe,const siritask::options& opt,
 				return e.arg( exe,configPath,cipherFolder ) ;
 			}else{
 
-				if( utility::platformIsOSX() ){
-
-					mode += " -o fsname=gocryptfs@" + cipherFolder ;
-				}
+				mode += " -o fsname=gocryptfs@" + cipherFolder ;
 
 				auto e = QString( "%1 %2 %3 %4 %5" ) ;
 				return e.arg( exe,mode,configPath,cipherFolder,mountPoint ) ;
@@ -300,9 +342,10 @@ static QString _args( const QString& exe,const siritask::options& opt,
 	}
 }
 
-static siritask::status _status( const siritask::volumeType& app,bool s )
+enum class status_type{ exeName,exeNotFound } ;
+static siritask::status _status( const siritask::volumeType& app,status_type s )
 {
-	if( s ){
+	if( s == status_type::exeNotFound ){
 
 		if( app == "cryfs" ){
 
@@ -316,7 +359,7 @@ static siritask::status _status( const siritask::volumeType& app,bool s )
 
 			return cs::securefsNotFound ;
 
-		}else if( app.startsWith( "ecryptfs" ) ){
+		}else if( _ecryptfs( app ) ){
 
 			return cs::ecryptfs_simpleNotFound ;
 		}else{
@@ -344,9 +387,16 @@ static siritask::status _status( const siritask::volumeType& app,bool s )
 	}
 }
 
-static siritask::cmdStatus _status( int q,siritask::status s,const QByteArray& msg )
+static siritask::cmdStatus _status( const utility::Task& r,siritask::status s,bool stdOut )
 {
-	siritask::cmdStatus e = { q,msg } ;
+	if( r.success() ){
+
+		return siritask::status::success ;
+	}
+
+	siritask::cmdStatus e = { r.exitCode(),stdOut ? r.stdOut() : r.stdError() } ;
+
+	const auto msg = e.msg().toLower() ;
 
 	/*
 	 *
@@ -358,23 +408,34 @@ static siritask::cmdStatus _status( int q,siritask::status s,const QByteArray& m
 
 	if( s == siritask::status::ecryptfs ){
 
-		if( msg.contains( "error: mount failed" ) ){
+		if( msg.contains( "operation not permitted" ) ){
 
-			e.setStatus( s ) ;
+			e = siritask::status::ecrypfsBadExePermissions ;
+
+		}else if( msg.contains( "error: mount failed" ) ){
+
+			e = s ;
 		}
 
 	}else if( s == siritask::status::cryfs ){
 
+		const auto& m = e.msg() ;
+
 		if( msg.contains( "password" ) ){
 
-			e.setStatus( s ) ;
+			e = s ;
+
+		}else if( m.contains( "This filesystem is for CryFS" ) &&
+			  m.contains( "It has to be migrated" ) ){
+
+			e = siritask::status::cryfsMigrateFileSystem ;
 		}
 
 	}else if( s == siritask::status::encfs ){
 
 		if( msg.contains( "password" ) ){
 
-			e.setStatus( s ) ;
+			e = s ;
 		}
 
 	}else if( s == siritask::status::gocryptfs ){
@@ -384,11 +445,11 @@ static siritask::cmdStatus _status( int q,siritask::status s,const QByteArray& m
 		 */
 		if( e.exitCode() == 12 ){
 
-			e.setStatus( s ) ;
+			e = s ;
 		}else{
 			if( msg.contains( "password" ) ){
 
-				e.setStatus( s ) ;
+				e = s ;
 			}
 		}
 
@@ -396,7 +457,7 @@ static siritask::cmdStatus _status( int q,siritask::status s,const QByteArray& m
 
 		if( msg.contains( "password" ) ){
 
-			e.setStatus( s ) ;
+			e = s ;
 		}
 	}
 
@@ -412,49 +473,52 @@ static siritask::cmdStatus _cmd( bool create,const siritask::options& opt,
 
 	if( exe.isEmpty() ){
 
-		return _status( app,true ) ;
+		return _status( app,status_type::exeNotFound ) ;
 	}else{
-		auto e = utility::Task( _args( exe,opt,configFilePath,create ),
-					20000,
-					utility::systemEnvironment(),
-					password.toLatin1(),
-					[](){},
-					_ecryptfs( opt.type ) ) ;
+		auto _run = [ & ](){
 
-		if( e.success() ){
+			auto s = utility::Task( _args( exe,opt,configFilePath,create ),
+						20000,
+						utility::systemEnvironment(),
+						password.toLatin1(),
+						[](){},
+						_ecryptfs_1( app ) ) ;
 
-			return cs::success ;
-		}
+			return _status( s,_status( app,status_type::exeName ),app == "encfs" ) ;
+		} ;
 
-		auto status = _status( e.exitCode(),_status( app,false ),[ & ](){
+		auto e = _run() ;
 
-			if( app == "encfs" ){
+		if( e == siritask::status::ecrypfsBadExePermissions ){
 
-				return e.stdOut().toLower() ;
-			}else{
-				return e.stdError().toLower() ;
-			}
-		}() ) ;
+			if( utility::enablePolkit( utility::background_thread::True ) ){
 
-		auto s = QString::number( status.exitCode() ) ;
-		auto m = status.msg() ;
-
-		while( true ){
-
-			if( m.endsWith( '\n' ) ){
-
-				m.truncate( m.size() - 1 ) ;
-			}else{
-				break ;
+				e = _run() ;
 			}
 		}
 
-		utility::debug() << "-------------------------" ;
-		utility::debug() << QString( "Backend Generated Output:\nExit Code: %1" ).arg( s ) ;
-		utility::debug() << QString( "Exit String: \"%1\"" ).arg( m ) ;
-		utility::debug() << "-------------------------" ;
+		if( e != siritask::status::success ){
 
-		return status ;
+			auto s = QString::number( e.exitCode() ) ;
+			auto m = e.msg() ;
+
+			while( true ){
+
+				if( m.endsWith( '\n' ) ){
+
+					m.truncate( m.size() - 1 ) ;
+				}else{
+					break ;
+				}
+			}
+
+			utility::debug() << "-------------------------" ;
+			utility::debug() << QString( "Backend Generated Output:\nExit Code: %1" ).arg( s ) ;
+			utility::debug() << QString( "Exit String: \"%1\"" ).arg( m ) ;
+			utility::debug() << "-------------------------" ;
+		}
+
+		return e ;
 	}
 }
 
@@ -470,7 +534,7 @@ static QString _configFilePath( const siritask::options& opt )
 
 Task::future< siritask::cmdStatus >& siritask::encryptedFolderMount( const options& opt,bool reUseMountPoint )
 {
-	return Task::run< siritask::cmdStatus >( [ opt,reUseMountPoint ]()->siritask::cmdStatus{
+	return Task::run( [ opt,reUseMountPoint ]()->siritask::cmdStatus{
 
 		auto _mount = [ reUseMountPoint ]( const QString& app,const options& copt,
 				const QString& configFilePath )->siritask::cmdStatus{
@@ -562,7 +626,7 @@ Task::future< siritask::cmdStatus >& siritask::encryptedFolderMount( const optio
 
 Task::future< siritask::cmdStatus >& siritask::encryptedFolderCreate( const options& opt )
 {
-	return Task::run< siritask::cmdStatus >( [ opt ]()->siritask::cmdStatus{
+	return Task::run( [ opt ]()->siritask::cmdStatus{
 
 		if( _create_folder( opt.cipherFolder ) ){
 
