@@ -51,8 +51,6 @@
 #include "../zuluCrypt-gui/tablewidget.h"
 #include "mountpartition.h"
 #include "oneinstance.h"
-#include "events.h"
-#include "monitor_mountinfo.h"
 #include "../zuluCrypt-gui/utility.h"
 #include "siritask.h"
 #include "zulumounttask.h"
@@ -69,8 +67,9 @@ static bool _encrypted_folder( const QString& e,bool f = true )
 
 zuluMount::zuluMount( QWidget * parent ) :
 	QWidget( parent ),
-	m_mountInfo( monitor_mountinfo::instance( this,true,[ this ](){ QCoreApplication::quit() ; } ) ),
-	m_events( events::instance( this,m_mountInfo->stop() ) )
+	m_mountInfo( this,true,[ this ](){ QCoreApplication::quit() ; } ),
+	m_events( this,m_mountInfo.stop() ),
+	m_checkForUpdates( this )
 {
 }
 
@@ -78,7 +77,7 @@ void zuluMount::helperStarted( bool start,const QString& volume )
 {
 	if( !start ){
 
-		DialogMsg( this ).ShowUIOK( tr( "ERROR" ),tr( "Failed To Start Helper Application.\n\"org.zulucrypt.zulupolkit.policy\" polkit file is either misconfigured or zuluPolkit executable could not be found." ) ) ;
+		DialogMsg( this ).ShowUIOK( tr( "ERROR" ),utility::failedToStartzuluPolkit() ) ;
 
 		return this->closeApplication() ;
 	}
@@ -343,7 +342,7 @@ void zuluMount::helperStarted( bool start,const QString& volume )
 
 	this->setLocalizationLanguage( false ) ;
 
-	m_trayIcon.show() ;
+	utility::showTrayIcon( nullptr,this,true ) ;
 
 	m_powerOff = utility::powerOffCommand() ;
 
@@ -368,6 +367,12 @@ void zuluMount::helperStarted( bool start,const QString& volume )
 	}
 }
 
+void zuluMount::showTrayIcon( bool e )
+{
+	Q_UNUSED( e ) ;
+	m_trayIcon.show() ;
+}
+
 void zuluMount::showTrayGUI()
 {
 	this->slotTrayClicked( QSystemTrayIcon::Trigger ) ;
@@ -389,12 +394,12 @@ void zuluMount::licenseInfo()
 
 void zuluMount::updateCheck()
 {
-	checkForUpdates::instance( this ) ;
+	m_checkForUpdates.run() ;
 }
 
 void zuluMount::autoUpdateCheck()
 {
-	checkForUpdates::instance( this,"zuluMount" ) ;
+	m_checkForUpdates.run( "zuluMount" ) ;
 }
 
 void zuluMount::removeVolumeFromHiddenVolumeList( QAction * ac )
@@ -551,8 +556,8 @@ bool zuluMount::autoOpenFolderOnMount( void )
 
 void zuluMount::startAutoMonitor()
 {
-	m_mountInfo->start() ;
-	m_events->start() ;
+	m_mountInfo.start() ;
+	m_events.start() ;
 }
 
 /*
@@ -561,13 +566,13 @@ void zuluMount::startAutoMonitor()
 void zuluMount::closeApplication()
 {
 	utility::quitHelper() ;
-	m_events->stop() ;
+	m_events.stop() ;
 }
 
 void zuluMount::closeApplication( int s )
 {
 	Q_UNUSED( s ) ;
-	m_events->stop() ;
+	m_events.stop() ;
 }
 
 void zuluMount::autoMountVolume( volumeProperty * q )
@@ -694,6 +699,11 @@ void zuluMount::raiseWindow( const QString& volume )
 	}
 }
 
+void zuluMount::polkitFailedWarning()
+{
+	DialogMsg( this ).ShowUIOK( tr( "ERROR" ),tr( "zuluMount Failed To Connect To zuluPolkit.\nPlease Report This Serious Bug." ) ) ;
+}
+
 void zuluMount::Show()
 {
 	auto l = QCoreApplication::arguments() ;
@@ -701,23 +711,18 @@ void zuluMount::Show()
 	m_startHidden  = l.contains( "-e" ) ;
 	m_folderOpener = utility::cmdArgumentValue( l,"-m",utility::fileManager() ) ;
 
-	if( utility::useZuluPolkit() ){
-
-		utility::setUID( getuid() ) ;
-	}else{
-		utility::setUID( utility::cmdArgumentValue( l,"-K","-1" ).toInt() ) ;
-	}
-
-	auto s = utility::homePath() + "/.zuluCrypt-socket" ;
-
-	utility::createHomeFolder() ;
-	utility::createFolderPath( s ) ;
+	auto s = utility::socketPath() ;
 
 	if( utility::configDirectoriesAreNotWritable( this ) ){
 
 		return this->closeApplication() ;
 	}
 
+	utility::polkitFailedWarning( [ this ](){
+
+		QMetaObject::invokeMethod( this,"polkitFailedWarning",Qt::QueuedConnection ) ;
+	} ) ;
+
 	oneinstance::instance( this,
 			       s + "/zuluMount-gui.socket",
 			       utility::cmdArgumentValue( l,"-d" ),
@@ -830,6 +835,126 @@ void zuluMount::cryfsVolumeProperties()
 	this->enableAll() ;
 }
 
+static void _volume_properties( const QString& cmd,const QString& arg,
+				QTableWidget * table,QWidget * w )
+{
+	auto exe = utility::executableFullPath( cmd ) ;
+
+	auto path = [ table ](){
+
+		auto row = table->currentRow() ;
+
+		if( row < 0 ){
+
+			return QString() ;
+		}else{
+			return utility::Task::makePath( table->item( row,0 )->text() ) ;
+		}
+	}() ;
+
+	if( exe.isEmpty() ){
+
+		DialogMsg( w ).ShowUIOK( QObject::tr( "ERROR" ),
+					 QObject::tr( "Failed To Find %1 Executable" ).arg( cmd ) ) ;
+	}else{
+		auto e = utility::Task::run( exe + arg + path,utility::Task::USEPOLKIT::False ).await() ;
+
+		if( e.success() ){
+
+			auto s = e.stdOut() ;
+
+			if( cmd == "gocryptfs" ){
+
+				s.replace( "Creator:      ","Creator: " ).replace( "\n","\n\n" ) ;
+			}
+
+			DialogMsg( w ).ShowUIInfo( QObject::tr( "INFORMATION" ),true,s ) ;
+		}else{
+			DialogMsg( w ).ShowUIOK( QObject::tr( "ERROR" ),
+						 QObject::tr( "Failed To Get Volume Properties" ) ) ;
+		}
+	}
+}
+
+void zuluMount::encfsProperties()
+{
+	this->disableAll() ;
+
+	_volume_properties( "encfsctl"," ",m_ui->tableWidget,this ) ;
+
+	this->enableAll() ;
+}
+
+void zuluMount::securefsProperties()
+{
+	this->disableAll() ;
+
+	_volume_properties( "securefs"," info ",m_ui->tableWidget,this ) ;
+
+	this->enableAll() ;
+}
+
+void zuluMount::gocryptfsProperties()
+{
+	this->disableAll() ;
+
+	_volume_properties( "gocryptfs"," -info ",m_ui->tableWidget,this ) ;
+
+	this->enableAll() ;
+}
+
+static QString _fs_properties( const QString& m )
+{
+	QFile f( "/proc/self/mountinfo" ) ;
+
+	f.open( QIODevice::ReadOnly ) ;
+
+	auto s = " " + m + " " ;
+
+	for( const auto& it : utility::split( f.readAll() ) ){
+
+		if( it.contains( s ) ){
+
+			return utility::split( it,' ' ).last() ;
+		}
+	}
+
+	return QString() ;
+}
+
+void zuluMount::ecryptfsProperties()
+{
+	this->disableAll() ;
+
+	auto s = [ this ](){
+
+		auto table = m_ui->tableWidget ;
+
+		auto item = table->currentItem() ;
+
+		if( item ){
+
+			return table->item( item->row(),1 )->text() ;
+		}else{
+			return QString() ;
+		}
+	}() ;
+
+	DialogMsg( this ).ShowUIInfo( tr( "INFORMATION" ),true,[ & ](){
+
+		auto e = _fs_properties( s ) ;
+
+		e.replace( ",","\n\n" ) ;
+		e.replace( "ro\n\n","mode=read only\n\n" ) ;
+		e.replace( "rw\n\n","mode=read and write\n\n" ) ;
+		e.replace( "="," = " ) ;
+
+		return e ;
+	}() ) ;
+
+	this->enableAll() ;
+}
+
 void zuluMount::showContextMenu( QTableWidgetItem * item,bool itemClicked )
 {
 	QMenu m ;
@@ -857,6 +982,26 @@ void zuluMount::showContextMenu( QTableWidgetItem * item,bool itemClicked )
 
 				connect( m.addAction( tr( "Properties" ) ),SIGNAL( triggered() ),
 					 this,SLOT( cryfsVolumeProperties() ) ) ;
+
+			}else if( fs == "gocryptfs" ){
+
+				connect( m.addAction( tr( "Properties" ) ),SIGNAL( triggered() ),
+					 this,SLOT( gocryptfsProperties() ) ) ;
+
+			}else if( fs == "securefs" ){
+
+				connect( m.addAction( tr( "Properties" ) ),SIGNAL( triggered() ),
+					 this,SLOT( securefsProperties() ) ) ;
+
+			}else if( fs == "encfs" ){
+
+				connect( m.addAction( tr( "Properties" ) ),SIGNAL( triggered() ),
+					 this,SLOT( encfsProperties() ) ) ;
+
+			}else if( fs == "ecryptfs" ){
+
+				connect( m.addAction( tr( "Properties" ) ),SIGNAL( triggered() ),
+					 this,SLOT( ecryptfsProperties() ) ) ;
 			}else{
 				m.addAction( tr( "Properties" ) )->setEnabled( false ) ;
 			}
@@ -1554,12 +1699,16 @@ void zuluMount::enableAll_1()
 	this->enableAll() ;
 }
 
-#define zuluMOUNT_AUTOPATH "/.zuluCrypt/zuluMount-gui.autoMountPartitions"
-
 bool zuluMount::autoMount()
 {
-	QFile f( utility::homePath() + zuluMOUNT_AUTOPATH ) ;
-	return f.exists() ;
+	auto& e = utility::settingsObject() ;
+
+	if( !e.contains( "AutoMountVolumes" ) ){
+
+		e.setValue( "AutoMountVolumes",true ) ;
+	}
+
+	return e.value( "AutoMountVolumes" ).toBool() ;
 }
 
 zuluMount::~zuluMount()
@@ -1569,19 +1718,9 @@ zuluMount::~zuluMount()
 		return ;
 	}
 
-	QFile f( utility::homePath() + zuluMOUNT_AUTOPATH ) ;
-
 	if( m_autoMountAction ){
 
-		if( m_autoMountAction->isChecked() ){
-
-			if( !f.exists() ){
-
-				f.open( QIODevice::WriteOnly ) ;
-			}
-		}else{
-			f.remove() ;
-		}
+		utility::settingsObject().setValue( "AutoMountVolumes",m_autoMountAction->isChecked() ) ;
 	}
 
 	auto q = m_ui->tableWidget ;
