@@ -28,6 +28,9 @@
 
 #include "volumeproperty.h"
 #include "../zuluCrypt-gui/secrets.h"
+#include "events.h"
+#include "monitor_mountinfo.h"
+#include "../zuluCrypt-gui/checkforupdates.h"
 
 class QCloseEvent ;
 class QAction ;
@@ -49,6 +52,8 @@ signals:
 	void result( int,QString ) ;
 	void unlistVolume( QString ) ;
 private slots:
+	void showTrayIcon( bool ) ;
+	void polkitFailedWarning( void ) ;
 	void helperStarted( bool,const QString& ) ;
 	void Show( void ) ;
 	void raiseWindow( const QString& = QString() ) ;
@@ -98,6 +103,10 @@ private slots:
 	void licenseInfo( void ) ;
 	void updateCheck( void ) ;
 	void languageMenu( QAction * ac ) ;
+	void encfsProperties( void ) ;
+	void securefsProperties( void ) ;
+	void gocryptfsProperties( void ) ;
+	void ecryptfsProperties( void ) ;
 private:
 	void setIcons( void ) ;
 	bool errorNotFound( int ) ;
@@ -146,8 +155,10 @@ private:
 
 	QSystemTrayIcon m_trayIcon ;
 
-	std::unique_ptr< monitor_mountinfo > m_mountInfo ;
-	std::unique_ptr< events > m_events ;
+	monitor_mountinfo m_mountInfo ;
+	events m_events ;
+
+	checkForUpdates m_checkForUpdates ;
 };
 
 #endif // MAINWINDOW_H
