@@ -136,12 +136,12 @@ volumeProperty _getVolumeProperties( const QString& e )
 
 Task::future< volumeProperty >& zuluMountTask::getVolumeProperties( const QString& e )
 {
-	return Task::run< volumeProperty >( [ e ](){ return _getVolumeProperties( e ) ; } ) ;
+	return Task::run( [ e ](){ return _getVolumeProperties( e ) ; } ) ;
 }
 
 Task::future< QString >& zuluMountTask::volumeProperties( const QString& v,const QString& volumeType )
 {
-	return Task::run< QString >( [ = ](){
+	return Task::run( [ = ](){
 
 		if( v.isEmpty() ){
 
@@ -225,12 +225,7 @@ utility::Task zuluMountTask::volumeUnmount( const QString& volumePath,const QStr
 
 Task::future< utility::Task >& zuluMountTask::unmountVolume( const QString& volumePath,const QString& volumeType,const QString& powerOffCommand )
 {
-	return Task::run< utility::Task >( [ = ](){ return zuluMountTask::volumeUnmount( volumePath,volumeType,powerOffCommand ) ; } ) ;
-}
-
-static QString _excludeVolumePath()
-{
-	return utility::homePath() + "/.zuluCrypt/zuluMount-gui-excludeVolumes" ;
+	return Task::run( [ = ](){ return zuluMountTask::volumeUnmount( volumePath,volumeType,powerOffCommand ) ; } ) ;
 }
 
 struct deviceList
@@ -321,40 +316,37 @@ static QString _getUniqueName( const QString& device )
 	return QString() ;
 }
 
-static QStringList _split( QFile& f )
-{
-	return utility::split( f.readAll() ) ;
-}
-
 void zuluMountTask::addVolumeToHiddenVolumeList( const QString& e )
 {
-	QFile f( _excludeVolumePath() ) ;
+	auto& settings = utility::settingsObject() ;
 
-	if( f.open( QIODevice::WriteOnly | QIODevice::Append ) ){
+	QStringList s ;
 
-		auto a = _getUniqueName( e ) ;
+	if( settings.contains( "ListOfHiddenVolumes" ) ){
 
-		if( !a.isEmpty() ){
+		s = settings.value( "ListOfHiddenVolumes" ).toStringList() ;
+	}
 
-			f.write( a.toLatin1() + "\n" ) ;
-		}
+	auto a = _getUniqueName( e ) ;
 
-		utility::changePathOwner( f ) ;
-		utility::changePathPermissions( f ) ;
+	if( !a.isEmpty() ){
+
+		s.append( a ) ;
+		settings.setValue( "ListOfHiddenVolumes",s ) ;
 	}
 }
 
 QStringList zuluMountTask::hiddenVolumeList()
 {
-	QFile f( _excludeVolumePath() ) ;
+	auto& settings = utility::settingsObject() ;
 
-	if( f.open( QIODevice::ReadOnly ) ){
+	if( settings.contains( "ListOfHiddenVolumes" ) ){
 
 		auto l = _getDevices() ;
 
-		decltype( _split( f ) ) e ;
+		QStringList e ;
 
-		auto g = _split( f ) ;
+		auto g = settings.value( "ListOfHiddenVolumes" ).toStringList() ;
 
 		for( const auto& it : l ){
 
@@ -372,13 +364,13 @@ QStringList zuluMountTask::hiddenVolumeList()
 
 void zuluMountTask::removeVolumeFromHiddenVolumeList( const QString& e )
 {
-	auto _get_hidden_volume_list = [](){
+	auto& settings = utility::settingsObject() ;
 
-		QFile f( _excludeVolumePath() ) ;
+	auto _get_hidden_volume_list = [ & ](){
 
-		if( f.open( QIODevice::ReadOnly ) ){
+		if( settings.contains( "ListOfHiddenVolumes" ) ){
 
-			return _split( f ) ;
+			return settings.value( "ListOfHiddenVolumes" ).toStringList() ;
 		}else{
 			return QStringList() ;
 		}
@@ -394,23 +386,9 @@ void zuluMountTask::removeVolumeFromHiddenVolumeList( const QString& e )
 		return l ;
 	} ;
 
-	auto _update_list = []( const QStringList& l ){
+	auto _update_list = [ & ]( const QStringList& l ){
 
-		if( !l.isEmpty() ){
-
-			QFile f( _excludeVolumePath() ) ;
-
-			if( f.open( QIODevice::WriteOnly | QIODevice::Truncate ) ){
-
-				for( const auto& it : l ){
-
-					f.write( it.toLatin1() + "\n" ) ;
-				}
-
-				utility::changePathOwner( f ) ;
-				utility::changePathPermissions( f ) ;
-			}
-		}
+		settings.setValue( "ListOfHiddenVolumes",l ) ;
 	} ;
 
 	_update_list( _remove_entry( _get_hidden_volume_list(),e ) ) ;
@@ -418,7 +396,7 @@ void zuluMountTask::removeVolumeFromHiddenVolumeList( const QString& e )
 
 Task::future< QVector< volumeProperty > >& zuluMountTask::updateVolumeList()
 {
-	return Task::run< QVector< volumeProperty > >( [](){
+	return Task::run( [](){
 
 		auto l = zuluMountTask::hiddenVolumeList() ;
 
