@@ -30,23 +30,18 @@
 #include <stdlib.h>
 #include <sys/stat.h>
 
+#include <iostream>
+
 #include <QTimer>
 #include <QDir>
 #include <QProcess>
 #include <QCoreApplication>
+#include <QFile>
 
 namespace utility
 {
 	struct Task
 	{
-		static ::Task::future< utility::Task >& run( const QString& exe,
-							     const QString& password )
-		{
-			return ::Task::run< utility::Task >( [ = ](){
-
-				return utility::Task( exe,password ) ;
-			} ) ;
-		}
 		Task()
 		{
 		}
@@ -102,8 +97,8 @@ static bool _terminalEchoOff( struct termios * old,struct termios * current )
 		return false ;
 	}
 
-	*current = *old;
-	current->c_lflag &= ~ECHO;
+	*current = *old ;
+	current->c_lflag &= ~ECHO ;
 
 	if( tcsetattr( 1,TCSAFLUSH,current ) != 0 ){
 
@@ -113,6 +108,47 @@ static bool _terminalEchoOff( struct termios * old,struct termios * current )
 	}
 }
 
+#if QT_VERSION > QT_VERSION_CHECK( 5,0,0 )
+	#include <QFileDevice>
+
+	#define zuluPermission QFileDevice
+#else
+	#define zuluPermission QFile
+#endif
+
+static utility::Task _zulupolkit( const QString& cmd,const QString& path,const QString& data )
+{
+	utility::Task s ;
+
+	QFile e( path ) ;
+
+	QDir().mkpath( "/etc/zuluCrypt" ) ;
+
+	auto q = zuluPermission::ReadOwner | zuluPermission::WriteOwner ;
+	QFile().setPermissions( "/etc/zuluCrypt",q | zuluPermission::ExeOwner ) ;
+
+	if( cmd == "Read" ){
+
+		if( e.open( QIODevice::ReadOnly ) ){
+
+			s.stdOut = e.readAll() ;
+			s.exitCode = 0 ;
+		}
+
+	}else if( cmd == "Write" ){
+
+		if( e.open( QIODevice::WriteOnly | QIODevice::Truncate ) ){
+
+			e.write( data.toLatin1() ) ;
+			s.exitCode = 0 ;
+		}
+	}
+
+	e.setPermissions( q ) ;
+
+	return s ;
+}
+
 zuluPolkit::zuluPolkit( const QStringList& s ) : m_arguments( s )
 {
 	connect( &m_server,SIGNAL( newConnection() ),this,SLOT( gotConnection() ) ) ;
@@ -123,6 +159,28 @@ zuluPolkit::~zuluPolkit()
 	QDir().remove( m_socketPath ) ;
 }
 
+static void _set_path_writable_by_others( const QString& e )
+{
+	QFile f( e ) ;
+
+	for( decltype( umask( 0 ) ) i = 0 ; i < 1000 ; i++ ){
+
+		umask( i ) ;
+
+		f.open( QIODevice::WriteOnly ) ;
+
+		auto s = f.permissions() ;
+
+		f.close() ;
+		f.remove() ;
+
+		if( s & zuluPermission::WriteOther ){
+
+			break ;
+		}
+	}
+}
+
 void zuluPolkit::start()
 {
 	if( m_arguments.size() > 1 ){
@@ -131,9 +189,15 @@ void zuluPolkit::start()
 
 		m_socketPath = m_arguments.at( 1 ) ;
 
-		QDir().remove( m_socketPath ) ;
+		QFile::remove( m_socketPath ) ;
+
+		auto s = umask( 0 ) ;
+
+		_set_path_writable_by_others( m_socketPath ) ;
 
 		m_server.listen( m_socketPath ) ;
+
+		umask( s ) ;
 	}
 }
 
@@ -171,6 +235,8 @@ void zuluPolkit::gotConnection()
 
 		auto json = nlohmann::json::parse( s->readAll().constData() ) ;
 
+		auto path     = QString::fromStdString( json[ "path" ].get< std::string >() ) ;
+		auto data     = QString::fromStdString( json[ "data" ].get< std::string >() ) ;
 		auto password = QString::fromStdString( json[ "password" ].get< std::string >() ) ;
 		auto cookie   = QString::fromStdString( json[ "cookie" ].get< std::string >() ) ;
 		auto command  = QString::fromStdString( json[ "command" ].get< std::string >() ) ;
@@ -181,6 +247,10 @@ void zuluPolkit::gotConnection()
 
 				return QCoreApplication::quit() ;
 
+			}else if( command == "Read" || command == "Write" ){
+
+				return _respond( s,_zulupolkit( command,path,data ) ) ;
+
 			}else if( _correct_cmd( command ) ){
 
 				return _respond( s,utility::Task( command,password ) ) ;
